@@ -157,7 +157,7 @@ struct CDRstruct64 {
 #define CDR_RFUa_OFFSET64       36
 #define CDR_RFUb_OFFSET64       40
 #define CDR_INCREMENT_OFFSET64  44
-#define CDR_RFUd_OFFSET64       48
+#define CDR_RFUd_OFFSET64       52
 #define CDR_RFUe_OFFSET64       52
 #define CDR_COPYRIGHT_OFFSET64  56
 
@@ -190,11 +190,13 @@ struct GDRstruct64 {
   Int32 NzVars;         /* Number of zVariables. */
   OFF_T UIRhead;        /* File offset to first UIR (bytes). */
   Int32 rfuC;           /* reserved for future use (value = 0) */
-  Int32 rfuD;           /* reserved for future use (value = -1) */
+  Int32 LeapSecondLastUpdated; /* Last leap second was added to the TT2000
+                                  table in YYYYMMDD form. */
   Int32 rfuE;           /* reserved for future use (value = -1) */
   Int32 rDimSizes[CDF_MAX_DIMS];
 			/* Size of each dimension (for rVariables). */
 };
+#define GDR_LEAPSECONDLASTUPDATED   14
 
 #define GDR_RECORDSIZE_OFFSET64 0
 #define GDR_RECORDTYPE_OFFSET64 8
@@ -209,7 +211,7 @@ struct GDRstruct64 {
 #define GDR_NzVARS_OFFSET64     60
 #define GDR_UIRHEAD_OFFSET64    64
 #define GDR_RFUc_OFFSET64       72
-#define GDR_RFUd_OFFSET64       76
+#define GDR_LEAPSECONDLASTUPDATED_OFFSET64       76
 #define GDR_RFUe_OFFSET64       80
 #define GDR_rDIMSIZES_OFFSET64  84
 
@@ -853,7 +855,13 @@ STATICforIDL CDFstatus DecompressToStage64 PROTOARGs((
 STATICforIDL CDFstatus FlushStage64 PROTOARGs((
   struct CDFstruct *CDF, struct VarStruct *Var
 ));
-
+STATICforIDL CDFstatus SetLeapSecondLastUpdate PROTOARGs((
+  struct CDFstruct *CDF, struct VarStruct *Var, Logical zVar
+));
+STATICforIDL CDFstatus ValidateCDF64 PROTOARGs((
+  struct CDFstruct *CDF, vFILE *vFp, OFF_T offset64, OFF_T fileSize,
+  Logical debug
+));
 #if defined(__cplusplus)
   extern "C" {
 #endif
@@ -899,12 +907,14 @@ VISIBLE_PREFIX CDFstatus CDFVerifyChecksum PROTOARGs((
 VISIBLE_PREFIX CDFstatus CDFAddChecksum PROTOARGs((
   struct CDFstruct *CDF
 ));
-VISIBLE_PREFIX CDFstatus ValidateCDF64 PROTOARGs((
-  struct CDFstruct *CDF, vFILE *vFp, OFF_T offset64, OFF_T fileSize,
-  Logical debug
-));
 VISIBLE_PREFIX void AddOpenCDFsCount PROTOARGs(());
 VISIBLE_PREFIX void ReduceOpenCDFsCount PROTOARGs(());
+VISIBLE_PREFIX int ValidateTT2000 PROTOARGs((
+  int tt2000YYYYMMDD, int leapSecondLastUpdated
+));
+VISIBLE_PREFIX int ValidateLeapSecondLastUpdated PROTOARGs((
+  int leapSecondLastUpdated
+));
 
 #if defined(__cplusplus)
   }
