@@ -1,4 +1,9 @@
 /******************************************************************************
+* Copyright 1996-2014 United States Government as represented by the
+* Administrator of the National Aeronautics and Space Administration.
+* All Rights Reserved.
+******************************************************************************/
+/******************************************************************************
 *
 *  NSSDC/CDF                                        CDF `create' operations.
 *
@@ -23,6 +28,7 @@
 *   V2.0  29-Jun-04, M Liu      Added LFS (Large File Support > 2G).
 *   V2.1  13-Oct-06, M Liu      Changed to allow upper and lower case CDF  
 *                               name to be used on win32.
+*   V3.5  23-Jul-13, M Liu      Changed to alternative encoding to IBMPC.
 *
 ******************************************************************************/
 
@@ -65,6 +71,8 @@ switch (Va->item) {
     uInt32 magicNumber1 = V3magicNUMBER_1;
     uInt32 magicNumber2u = V3magicNUMBER_2u;
     char CDFnamePx[CDF_PATHNAME_LEN+1];
+    char *del = NULL;
+    long year, month, day;
     /**************************************************************************
     * Get arguments for this operation/item.
     **************************************************************************/
@@ -94,7 +102,25 @@ switch (Va->item) {
 #if defined(vms) || defined(dos)
     MakeUpperString (CDFnameT);
 #endif
+#if defined(unix) || defined(win32) || defined(dos)
+# if defined(unix)
+    del = strrchr(CDFnameT, '/');
+# else
+    del = strrchr(CDFnameT, '\\');
+    if (del == NULL) {
+#     if defined(win32)
+        del = strrchr(CDFnameT, '/');
+#     endif
+    }
+# endif
+    if (del == NULL) {
+      if (!ValidCDFname(CDFnameT)) return BAD_CDF_NAME;
+    } else {
+      if (!ValidCDFname(del+1)) return BAD_CDF_NAME;
+    }
+#else
     if (!ValidCDFname(CDFnameT)) return BAD_CDF_NAME;
+#endif
     BuildFilePath (CDFt, CDFnameT, no_append, upper_case_ext, version_numbers,
 		   INT32_ZERO, CDFnameX);
     if (IsReg(CDFnameX)) return CDF_EXISTS;
@@ -106,13 +132,13 @@ switch (Va->item) {
     /**************************************************************************
     * Allocate/initialize CDF structure.
     **************************************************************************/
-    CDF = (struct CDFstruct *) cdf_AllocateMemory (sizeof(struct CDFstruct), NULL);
+    CDF = (struct CDFstruct *) cdf_AllocateMemory ((size_t)sizeof(struct CDFstruct), NULL);
     if (CDF == NULL) {
       V_close64 (dotFp, NULL, NULL);
       DeleteFile (CDFnameX);
       return BAD_MALLOC;
     }
-    CDF->CDFname = (char *) cdf_AllocateMemory (strlen(CDFnameT) + 1, NULL);
+    CDF->CDFname = (char *) cdf_AllocateMemory ((size_t)strlen(CDFnameT) + 1, NULL);
     if (CDF->CDFname == NULL) {
       V_close64 (dotFp, NULL, NULL);
       DeleteFile (CDFnameX);
@@ -149,7 +175,7 @@ switch (Va->item) {
     CDF->rVars = NULL;
     CDF->zVars = NULL;
     CDF->encoding = BOO(DEFAULT_TO_HOST_ENCODING,HostEncoding(),
-			NETWORK_ENCODING);
+			IBMPC_ENCODING);
     CDF->rowMajor = DEFAULT_TO_ROW_MAJOR;
     CDF->singleFile = DEFAULT_TO_SINGLE_FILE;
     CDF->rMaxRec = NO_RECORD;
@@ -165,6 +191,7 @@ switch (Va->item) {
     CDF->workingCacheSize = BOO(CDF->singleFile,NUMcacheSINGLE,NUMcacheMULTI);
     CDF->compressCacheSize = NUMcacheCOMPRESS;
     CDF->checksum = BOO(CDFgetChecksumEnvVar()<=0,NONE_CHECKSUM,MD5_CHECKSUM);
+    CDF->leapSecondUpdated = 1;
     InitCURobjectsStates (CDF);
     AddTOvStats (&CDF->dotCDFvStats, NULL);
     AddTOvStats (&CDF->uDotCDFvStats, NULL);
@@ -232,7 +259,12 @@ switch (Va->item) {
     GDR.NzVars = CDF->NzVars;
     GDR.UIRhead = (OFF_T) 0;
     GDR.rfuC = 0;
-    GDR.rfuD = -1;
+#if defined(vms)
+    CDFgetLastDateinLeapSecondsTBL (&year, &month, &day);
+#else
+    CDFgetLastDateinLeapSecondsTable (&year, &month, &day);
+#endif
+    GDR.LeapSecondLastUpdated = (Int32) (10000*year + 100*month + day);
     GDR.rfuE = -1;
     for (dimN = 0; dimN < CDF->rNumDims; dimN++) {
        GDR.rDimSizes[dimN] = CDF->rDimSizes[dimN];
@@ -259,7 +291,6 @@ switch (Va->item) {
   /****************************************************************************
   * rVAR_/zVAR_, create a new variable.
   ****************************************************************************/
-
   case rVAR_:
   case zVAR_: {
     Logical zOp = (Va->item == zVAR_);
@@ -275,6 +306,8 @@ switch (Va->item) {
     int dimN, *max;
     OFF_T offset, ntlOffset, VDRhead;
     int ttmmpp;
+    Int32 padSize, toPad;
+    void *pad;
     name = va_arg (Va->ap, char *);
     dataType = (Int32) va_arg (Va->ap, long);
     numElements = (Int32) va_arg (Va->ap, long);
@@ -351,7 +384,7 @@ switch (Va->item) {
       if (*max > 0)
 	ptr = (struct VarStruct **) cdf_ReallocateMemory (*vars, nBytes, NULL);
       else
-	ptr = (struct VarStruct **) cdf_AllocateMemory (nBytes, NULL);
+	ptr = (struct VarStruct **) cdf_AllocateMemory ((size_t)nBytes, NULL);
       if (ptr == NULL) return BAD_MALLOC;
       *vars = ptr;
       for (varN = *max; varN < newMaxVars; varN++) (*vars)[varN] = NULL;
@@ -411,18 +444,25 @@ switch (Va->item) {
 	 dimN < numDims; dimN++) {
        VDR.DimVarys[dimN] = BOO(dimVariances[dimN],VARY,NOVARY);
     }
-    if (!sX(AllocateIR64(CDF,VDR.RecordSize,&offset),&pStatus)) {
+    padSize = (int) (CDFelemSize(dataType) * numElements);
+    pad = (void *) cdf_AllocateMemory((size_t)padSize, NULL);
+    if (!sX(AllocateIR64(CDF,VDR.RecordSize+padSize,&offset),&pStatus)) {
       DeleteFile (pathnameX);
       AbortAccess64 (CDF, UPDATE, noDELETE);
       return pStatus;
     }
+    toPad = VDR.RecordSize;
+    DefaultPadValue(dataType, numElements, pad);
+    VDR.RecordSize += padSize;
+    SetBit32 (&VDR.Flags,VDR_PADVALUE_BIT);
     if (!sX(WriteVDR64(CDF,CDF->fp,offset,zOp,
-		       VDR_RECORD,&VDR,NULL,
+		       VDR_RECORD,&VDR,pad,
 		       VDR_NULL),&pStatus)) {
       DeleteFile (pathnameX);
       AbortAccess64 (CDF, UPDATE, noDELETE);
       return pStatus;
     }
+    cdf_FreeMemory (pad, NULL);
     /**************************************************************************
     * Point next-to-last rVDR/zVDR (or GDR) to this rVDR/zVDR.
     **************************************************************************/
