@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -510,11 +510,10 @@ void *buffer;
 		cdf_FreeMemory(phyBuffer,NULL);
 		return pStatus;
 	      }
-	      else { /* Don't want it to stop. */
-		pStatus = CDF_OK;
-	      }
 	    }
 	 }
+	 if (pStatus == VIRTUAL_RECORD_DATA) /* Don't want it to stop. */
+	   pStatus = CDF_OK;
 	 if (!sX(HyperWriteDim64(Var->numDims,Var->dimSizes,
 			         Var->dimVarys,rd->dimIndices,
 			         rd->dimCounts,rd->dimIntervals,
@@ -557,11 +556,10 @@ void *buffer;
 	   cdf_FreeMemory(phyBuffer,NULL);
 	   return pStatus;
 	 }
-	 else { /* Don't want it to stop */
-	   pStatus = CDF_OK;
-	 }
        } 
     }
+    if (pStatus != VIRTUAL_RECORD_DATA) /* Don't want it to stop */
+      pStatus = CDF_OK;
     if (!sX(HyperWriteDim64(Var->numDims,Var->dimSizes,Var->dimVarys,
 			    rd->dimIndices,rd->dimCounts,
 			    rd->dimIntervals,nHypDimValues,
