@@ -1,5 +1,5 @@
 /******************************************************************************
-* Copyright 1996-2013 United States Government as represented by the
+* Copyright 1996-2014 United States Government as represented by the
 * Administrator of the National Aeronautics and Space Administration.
 * All Rights Reserved.
 ******************************************************************************/
@@ -755,7 +755,7 @@ Logical *version;       /* Should a version number of `;1' be appended? */
     return CDF_OK;
   }
 
-#if defined(unix) || defined(dos)
+#if defined(unix) || defined(dos) || defined(win32) 
   strcpyX (pathT, path, DU_MAX_PATH_LEN);
   MakeUpperString (pathT);
   strcatX (pathT, ".CDF", DU_MAX_PATH_LEN);
@@ -1836,8 +1836,10 @@ Logical deleteCDF;      /* Delete CDF file(s)? */
     /**************************************************************************
     * Close all of the CDF files if they are not already closed (or deleted).
     **************************************************************************/
-    if (CDF->dotFp != NULL) V_close (CDF->dotFp, CDF, NULL);
-    if (CDF->uDotFp != NULL) V_close (CDF->uDotFp, CDF, NULL);
+    if (CDF->dotFp != NULL) V_close (CDF->dotFp,
+				     ((updateCDF==UPDATE)?CDF:NULL), NULL);
+    if (CDF->uDotFp != NULL) V_close (CDF->uDotFp,
+				      ((updateCDF==UPDATE)?CDF:NULL), NULL);
     CloseVarFiles (CDF);
   }
   /****************************************************************************
@@ -2000,23 +2002,23 @@ Int32 eOffset;
 ******************************************************************************/
 
 #if defined(MPW_C)
-STATICforIDL unsigned char *CtoPstr (string)
+STATICforIDL uChar *CtoPstr (string)
 char *string;
 {
   size_t length = MINIMUM(strlen(string),255);
   if (length > 0) memmove (&string[1], string, length);
   string[0] = (char) length;
-  return ((unsigned char *) string);
+  return ((uChar *) string);
 }
 #endif
 
 #if defined(MPW_C)
 STATICforIDL char *PtoCstr (string)
-unsigned char *string;
+uChar *string;
 {
   size_t length = (size_t) string[0];
   if (length > 0) memmove (string, &string[1], length);
-  string[length] = (unsigned char) NUL;
+  string[length] = (uChar) NUL;
   return ((char *) string);
 }
 #endif
