@@ -38,6 +38,8 @@
 #include "cdflib64.h"
 #include "cdfrev.h"
 
+static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars);
+
 /******************************************************************************
 * CDFope.
 ******************************************************************************/
@@ -516,6 +518,16 @@ switch (Va->item) {
         return pStatus;
       }
     }
+    if (CDFgetValidate() && (!PriorTo ("3.5.0", version, release, increment))) {
+      if (!sX(ValidateCDFTT2000 (*id, (int) CDF->NzVars, (int) CDF->NrVars),
+              &pStatus)) {
+        AbortAccess (CDF, noUPDATE, noDELETE);
+        cdf_FreeMemory (CDF, NULL);
+        Cur->cdf = NULL;
+        *id = (CDFid) NULL;
+        return pStatus;
+      }
+    }
     AddOpenCDFsCount();
     break;
   }
@@ -530,3 +542,93 @@ switch (Va->item) {
 
 return pStatus;
 }
+
+/******************************************************************************
+* ValidateCDFTT2000.
+******************************************************************************/
+
+static CDFstatus ValidateCDFTT2000 (CDFid id, int zVars, int rVars)
+{
+  long maxRec, dataType;
+  CDFstatus status;
+  int i, tt2000Sts;
+  long j, count;
+  long long tt2000 = DEFAULT_TT2000_PADVALUE;
+  void *buffer;
+  long tt2000LastUpdated, numDims, dimSizes[CDF_MAX_DIMS];
+  double yy, mm, dd, hh, mn, ss, ml, ms, ns;
+
+  status = CDFgetLeapSecondLastUpdated (id, &tt2000LastUpdated);
+  if (status != CDF_OK) return status;
+  if (tt2000LastUpdated == 0) return CDF_OK;
+  for (i = 0; i < zVars; ++i) {
+    status = CDFlib(SELECT_, zVAR_, (long) i,
+                    GET_, zVAR_DATATYPE_, &dataType,
+                    NULL_);
+    if (status != CDF_OK) return status;
+    if (dataType != CDF_TIME_TT2000) continue;
+    status = CDFlib(GET_, zVAR_MAXREC_, &maxRec,
+                    NULL_);
+    if (status != CDF_OK) return status;
+    if (maxRec < 0) continue;
+    status = CDFlib(GET_, zVAR_NUMDIMS_, &numDims,
+                          zVAR_DIMSIZES_, dimSizes,
+                    NULL_);
+    if (status != CDF_OK) return status;
+    count = maxRec + 1;
+    if (numDims > 0)
+      for (j = 0; j < (int) numDims; ++j) count *= dimSizes[j];
+    buffer = (void *) malloc ((size_t) (count * sizeof(long long)));
+    if (buffer == NULL) return BAD_MALLOC;
+    status =  CDFgetVarAllRecordsByVarID (id, 1, (long) i, buffer);
+    if (status < CDF_OK) {
+      free (buffer);
+      return status;
+    } 
+    for (j = 0; j < count; ++j) {
+      if (tt2000 < *(((long long *)buffer)+j))
+        tt2000 = *(((long long *)buffer)+j);
+    }
+    free (buffer);
+  }
+  status = CDFlib(GET_, rVARs_NUMDIMS_, &numDims,
+                        rVARs_DIMSIZES_, dimSizes,
+                  NULL_);
+  if (status != CDF_OK) return status;
+  for (i = 0; i < rVars; ++i) {
+    status = CDFlib(SELECT_, rVAR_, (long) i,
+                    GET_, rVAR_DATATYPE_, &dataType,
+                    NULL_);
+    if (status != CDF_OK) return status;
+    if (dataType != CDF_TIME_TT2000) continue;
+    status = CDFlib(GET_, rVAR_MAXREC_, &maxRec,
+                    NULL_);
+    if (status != CDF_OK) return status;
+    if (maxRec < 0) continue;
+    count = maxRec + 1;
+    if (numDims > 0) 
+      for (j = 0; j < (int) numDims; ++j) count *= dimSizes[j];
+    buffer = (void *) malloc ((size_t) (count * sizeof(long long)));
+    if (buffer == NULL) return BAD_MALLOC;
+    status =  CDFgetVarAllRecordsByVarID (id, 0, (long) i, buffer);
+    if (status < CDF_OK) {
+      free (buffer);
+      return status;
+    }
+    for (j = 0; j < count; ++j) {
+      if (tt2000 < *(((long long *)buffer)+j))
+        tt2000 = *(((long long *)buffer)+j);
+    }
+    free (buffer);
+  }
+  if (tt2000 != DEFAULT_TT2000_PADVALUE) {
+    breakdownTT2000 (tt2000, &yy, &mm, &dd, &hh, &mn, &ss, &ml, &ms, &ns);
+    tt2000Sts = ValidateTT2000((int) (10000*yy+100*mm+dd),
+                               (int)tt2000LastUpdated);
+    if (tt2000Sts == -1) return TT2000_USED_OUTDATED_TABLE;
+    else if (tt2000Sts == 0) return TT2000_CDF_MAYNEEDUPDATE;
+  }
+  return CDF_OK;
+}
+
+
