@@ -174,6 +174,13 @@ switch (Va->item) {
     break;
   }
   /****************************************************************************
+  * CDF_LEAPSECONDLASTUPDATED, 
+  ****************************************************************************/
+  case CDF_LEAPSECONDLASTUPDATED_: {
+    long lastUpdated = va_arg (Va->ap, long);         /* Compression type. */
+    break;
+  }
+  /****************************************************************************
   * CDF_COMPRESSION_
   ****************************************************************************/
   case CDF_COMPRESSION_: {
