@@ -764,6 +764,28 @@ switch (Va->item) {
     break;
   }
   /****************************************************************************
+  * CDF_LEAPSECONDLASTUPDATED_, 
+  ****************************************************************************/
+  case CDF_LEAPSECONDLASTUPDATED_: {
+    struct CDFstruct *CDF;
+    long lastUpdated = va_arg (Va->ap, long);
+    Int32 lastUpdatedT;
+    SelectCDF (Cur->cdf, CDF)
+    if (lastUpdated != 0) {
+      if (ValidateLeapSecondLastUpdated((int)lastUpdated) != 1)
+      return BADDATE_LEAPSECOND_UPDATED;
+    }
+    if (!WriteAccess64(CDF,FALSE,&pStatus)) return pStatus;
+    lastUpdatedT = (Int32) lastUpdated;
+    if (!sX(WriteGDR64(CDF->fp,CDF->GDRoffset64,
+                       GDR_LEAPSECONDLASTUPDATED,&lastUpdatedT,
+                       GDR_NULL),&pStatus)) {
+      AbortAccess64 (CDF, UPDATE, noDELETE);
+      return pStatus;
+    }
+    break;
+  }
+  /****************************************************************************
   * gENTRY_DATASPEC_/rENTRY_DATASPEC_/zENTRY_DATASPEC_, change the data
   * specification of an existing entry.  Currently, only the data type can
   * be changed (and must be equivalent).  The number of elements must remain
