@@ -84,7 +84,7 @@ int count;
 #else
   int i; Int32 temp[MAX_READ32s];
   if (count == 0) return TRUE;
-  if (count < 0 || count > MAX_READ32s) return FALSE; 
+  if (count < 0 || count > MAX_READ32s) return FALSE;
   if (!READv64(temp,(size_t)4,(size_t)count,fp)) return FALSE;
   for (i = 0; i < count; i++) {
      REVERSE4bIO (&temp[i], &buffer[i])
@@ -131,7 +131,7 @@ int count;
 #else
   int i; OFF_T temp[MAX_READ64s];
   if (count == 0) return TRUE;
-  if (count < 0 || count > MAX_READ64s) return FALSE; 
+  if (count < 0 || count > MAX_READ64s) return FALSE;
   if (!READv64(temp,(size_t)8,(size_t)count,fp)) return FALSE;
   for (i = 0; i < count; i++) {
      REVERSE8bIO (&temp[i], &buffer[i])
@@ -211,15 +211,20 @@ va_dcl
 	 if (!Read64_64(fp,&(CDR->RecordSize))) return CRE;
 	 if (!Read32_64(fp,&(CDR->RecordType))) return CRE;
 	 if (!Read64_64(fp,&(CDR->GDRoffset))) return CRE;
-	 if (!Read32_64(fp,&(CDR->Version))) return CRE;
-	 if (!Read32_64(fp,&(CDR->Release))) return CRE;
-	 if (!Read32_64(fp,&(CDR->Encoding))) return CRE;
-	 if (!Read32_64(fp,&(CDR->Flags))) return CRE;
-	 if (!Read32_64(fp,&(CDR->rfuA))) return CRE;
-	 if (!Read32_64(fp,&(CDR->rfuB))) return CRE;
-	 if (!Read32_64(fp,&(CDR->Increment))) return CRE;
-	 if (!Read32_64(fp,&(CDR->rfuD))) return CRE;
-	 if (!Read32_64(fp,&(CDR->rfuE))) return CRE;
+         /* group read for Version, Release, Encoding, Flags, rfuA, rfuB,
+            Increment, rfuD, rfuE -- all 4-byte big-endian. */
+         if (!Read32s_64(fp,&(CDR->Version),9)) return CRE;
+         /*
+  	   if (!Read32_64(fp,&(CDR->Version))) return CRE;
+	   if (!Read32_64(fp,&(CDR->Release))) return CRE;
+	   if (!Read32_64(fp,&(CDR->Encoding))) return CRE;
+	   if (!Read32_64(fp,&(CDR->Flags))) return CRE;
+	   if (!Read32_64(fp,&(CDR->rfuA))) return CRE;
+  	   if (!Read32_64(fp,&(CDR->rfuB))) return CRE;
+	   if (!Read32_64(fp,&(CDR->Increment))) return CRE;
+	   if (!Read32_64(fp,&(CDR->rfuD))) return CRE;
+	   if (!Read32_64(fp,&(CDR->rfuE))) return CRE;
+         */
 	 if (copyRight != NULL) {
 	   if (!READv64(copyRight,CDF_COPYRIGHT_LEN,1,fp)) return CRE;
 	   NulPad (copyRight, CDF_COPYRIGHT_LEN);
@@ -308,19 +313,34 @@ va_dcl
       if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
       if (!Read64_64(fp,&(fp->GDR64->RecordSize))) return CRE;
       if (!Read32_64(fp,&(fp->GDR64->RecordType))) return CRE;
-      if (!Read64_64(fp,&(fp->GDR64->rVDRhead))) return CRE;
-      if (!Read64_64(fp,&(fp->GDR64->zVDRhead))) return CRE;
-      if (!Read64_64(fp,&(fp->GDR64->ADRhead))) return CRE;
-      if (!Read64_64(fp,&(fp->GDR64->eof))) return CRE;
-      if (!Read32_64(fp,&(fp->GDR64->NrVars))) return CRE;
-      if (!Read32_64(fp,&(fp->GDR64->NumAttr))) return CRE;
-      if (!Read32_64(fp,&(fp->GDR64->rMaxRec))) return CRE;
-      if (!Read32_64(fp,&(fp->GDR64->rNumDims))) return CRE;
-      if (!Read32_64(fp,&(fp->GDR64->NzVars))) return CRE;
+      /* group read for rVDRhead, zVDRhead, ADRhead, eof -- all 8-bytei
+         big-endian */
+      if (!Read64s_64(fp,&(fp->GDR64->rVDRhead),4)) return CRE;
+      /*
+        if (!Read64_64(fp,&(fp->GDR64->rVDRhead))) return CRE;
+        if (!Read64_64(fp,&(fp->GDR64->zVDRhead))) return CRE;
+        if (!Read64_64(fp,&(fp->GDR64->ADRhead))) return CRE;
+        if (!Read64_64(fp,&(fp->GDR64->eof))) return CRE;
+      */
+      /* group read for NrVars, NumAttr, rMaxRec, rNumDims, NzVars -- all
+         4-byte big-endian */
+      if (!Read32s_64(fp,&(fp->GDR64->NrVars),5)) return CRE;
+      /*
+        if (!Read32_64(fp,&(fp->GDR64->NrVars))) return CRE;
+        if (!Read32_64(fp,&(fp->GDR64->NumAttr))) return CRE;
+        if (!Read32_64(fp,&(fp->GDR64->rMaxRec))) return CRE;
+        if (!Read32_64(fp,&(fp->GDR64->rNumDims))) return CRE;
+        if (!Read32_64(fp,&(fp->GDR64->NzVars))) return CRE;
+      */
       if (!Read64_64(fp,&(fp->GDR64->UIRhead))) return CRE;
-      if (!Read32_64(fp,&(fp->GDR64->rfuC))) return CRE;
-      if (!Read32_64(fp,&(fp->GDR64->rfuD))) return CRE;
-      if (!Read32_64(fp,&(fp->GDR64->rfuE))) return CRE;
+      /* group read for rfuC, LeapSecondLastUpdated, rfuE -- all 4-byte
+         big-endian */
+      if (!Read32s_64(fp,&(fp->GDR64->rfuC),3)) return CRE;
+      /*
+        if (!Read32_64(fp,&(fp->GDR64->rfuC))) return CRE;
+        if (!Read32_64(fp,&(fp->GDR64->LeapSecondLastUpdated))) return CRE;
+        if (!Read32_64(fp,&(fp->GDR64->rfuE))) return CRE;
+      */
       if (fp->GDR64->rNumDims < 0 ||
           fp->GDR64->rNumDims > CDF_MAX_DIMS) return CV3C; 
       if (!Read32s_64(fp,fp->GDR64->rDimSizes,
@@ -345,19 +365,28 @@ va_dcl
 	     if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	     if (!Read64_64(fp,&(GDR->RecordSize))) return CRE;
 	     if (!Read32_64(fp,&(GDR->RecordType))) return CRE;
-	     if (!Read64_64(fp,&(GDR->rVDRhead))) return CRE;
-	     if (!Read64_64(fp,&(GDR->zVDRhead))) return CRE;
-	     if (!Read64_64(fp,&(GDR->ADRhead))) return CRE;
-	     if (!Read64_64(fp,&(GDR->eof))) return CRE;
-	     if (!Read32_64(fp,&(GDR->NrVars))) return CRE;
-	     if (!Read32_64(fp,&(GDR->NumAttr))) return CRE;
-	     if (!Read32_64(fp,&(GDR->rMaxRec))) return CRE;
-	     if (!Read32_64(fp,&(GDR->rNumDims))) return CRE;
-	     if (!Read32_64(fp,&(GDR->NzVars))) return CRE;
+             if (!Read64s_64(fp,&(GDR->rVDRhead),4)) return CRE;
+             /*
+	       if (!Read64_64(fp,&(GDR->rVDRhead))) return CRE;
+	       if (!Read64_64(fp,&(GDR->zVDRhead))) return CRE;
+	       if (!Read64_64(fp,&(GDR->ADRhead))) return CRE;
+	       if (!Read64_64(fp,&(GDR->eof))) return CRE;
+             */
+             if (!Read32s_64(fp,&(GDR->NrVars),5)) return CRE;
+             /*
+	       if (!Read32_64(fp,&(GDR->NrVars))) return CRE;
+	       if (!Read32_64(fp,&(GDR->NumAttr))) return CRE;
+	       if (!Read32_64(fp,&(GDR->rMaxRec))) return CRE;
+	       if (!Read32_64(fp,&(GDR->rNumDims))) return CRE;
+	       if (!Read32_64(fp,&(GDR->NzVars))) return CRE;
+             */
 	     if (!Read64_64(fp,&(GDR->UIRhead))) return CRE;
-	     if (!Read32_64(fp,&(GDR->rfuC))) return CRE;
-	     if (!Read32_64(fp,&(GDR->rfuD))) return CRE;
-	     if (!Read32_64(fp,&(GDR->rfuE))) return CRE;
+             if (!Read32s_64(fp,&(GDR->rfuC),3)) return CRE;
+             /*
+	       if (!Read32_64(fp,&(GDR->rfuC))) return CRE;
+	       if (!Read32_64(fp,&(GDR->LeapSecondLastUpdated))) return CRE;
+	       if (!Read32_64(fp,&(GDR->rfuE))) return CRE;
+             */
              if (GDR->rNumDims < 0 ||
                  GDR->rNumDims > CDF_MAX_DIMS) break; /* return CV3C; */
 	     if (!Read32s_64(fp,GDR->rDimSizes,(int)GDR->rNumDims)) return CRE;
@@ -377,7 +406,7 @@ va_dcl
 	     GDR->NzVars = fp->GDR64->NzVars;
 	     GDR->UIRhead = fp->GDR64->UIRhead;
 	     GDR->rfuC = fp->GDR64->rfuC;
-	     GDR->rfuD = fp->GDR64->rfuD;
+	     GDR->LeapSecondLastUpdated = fp->GDR64->LeapSecondLastUpdated;
 	     GDR->rfuE = fp->GDR64->rfuE;
              for (i = 0; i < GDR->rNumDims; i++)
              {
@@ -562,6 +591,17 @@ va_dcl
                };
                break;
            };
+	   case GDR_LEAPSECONDLASTUPDATED: {
+               if (read_only_mode == READONLYoff)
+               {
+                   tOffset +=(OFF_T) GDR_LEAPSECONDLASTUPDATED_OFFSET64; break;
+               }
+               else
+               {
+                   *buffer = fp->GDR64->LeapSecondLastUpdated; 
+               };
+               break;
+           };
 	   default: return CDF_INTERNAL_ERROR;
 	 }
          if (read_only_mode == READONLYoff)
@@ -629,17 +669,26 @@ va_dcl
 	     if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
              if (!Read64_64(fp,&(ADR->RecordSize))) return CRE;
              if (!Read32_64(fp,&(ADR->RecordType))) return CRE;
-             if (!Read64_64(fp,&(ADR->ADRnext))) return CRE;
-             if (!Read64_64(fp,&(ADR->AgrEDRhead))) return CRE;
-             if (!Read32_64(fp,&(ADR->Scope))) return CRE;
-             if (!Read32_64(fp,&(ADR->Num))) return CRE;
-             if (!Read32_64(fp,&(ADR->NgrEntries))) return CRE;
-             if (!Read32_64(fp,&(ADR->MAXgrEntry))) return CRE;
-             if (!Read32_64(fp,&(ADR->rfuA))) return CRE;
+             if (!Read64s_64(fp,&(ADR->ADRnext),2)) return CRE;
+             /*
+               if (!Read64_64(fp,&(ADR->ADRnext))) return CRE;
+               if (!Read64_64(fp,&(ADR->AgrEDRhead))) return CRE;
+             */
+             if (!Read32s_64(fp,&(ADR->Scope),5)) return CRE;
+             /*
+               if (!Read32_64(fp,&(ADR->Scope))) return CRE;
+               if (!Read32_64(fp,&(ADR->Num))) return CRE;
+               if (!Read32_64(fp,&(ADR->NgrEntries))) return CRE;
+               if (!Read32_64(fp,&(ADR->MAXgrEntry))) return CRE;
+               if (!Read32_64(fp,&(ADR->rfuA))) return CRE;
+             */
              if (!Read64_64(fp,&(ADR->AzEDRhead))) return CRE;
-             if (!Read32_64(fp,&(ADR->NzEntries))) return CRE;
-             if (!Read32_64(fp,&(ADR->MAXzEntry))) return CRE;
-             if (!Read32_64(fp,&(ADR->rfuE))) return CRE;
+             if (!Read32s_64(fp,&(ADR->NzEntries),3)) return CRE;
+             /*
+               if (!Read32_64(fp,&(ADR->NzEntries))) return CRE;
+               if (!Read32_64(fp,&(ADR->MAXzEntry))) return CRE;
+               if (!Read32_64(fp,&(ADR->rfuE))) return CRE;
+             */
              if (!READv64(ADR->Name,CDF_ATTR_NAME_LEN256,1,fp)) return CRE;
              NulPad (ADR->Name, CDF_ATTR_NAME_LEN256);
          }
@@ -900,15 +949,18 @@ va_dcl
              if (!Read64_64(fp,&(AEDR->RecordSize))) return CRE;
              if (!Read32_64(fp,&(AEDR->RecordType))) return CRE;
              if (!Read64_64(fp,&(AEDR->AEDRnext))) return CRE;
-             if (!Read32_64(fp,&(AEDR->AttrNum))) return CRE;
-             if (!Read32_64(fp,&(AEDR->DataType))) return CRE;
-             if (!Read32_64(fp,&(AEDR->Num))) return CRE;
-             if (!Read32_64(fp,&(AEDR->NumElems))) return CRE;
-             if (!Read32_64(fp,&(AEDR->rfuA))) return CRE;
-             if (!Read32_64(fp,&(AEDR->rfuB))) return CRE;
-             if (!Read32_64(fp,&(AEDR->rfuC))) return CRE;
-             if (!Read32_64(fp,&(AEDR->rfuD))) return CRE;
-             if (!Read32_64(fp,&(AEDR->rfuE))) return CRE;
+             if (!Read32s_64(fp,&(AEDR->AttrNum),9)) return CRE;
+             /*
+               if (!Read32_64(fp,&(AEDR->AttrNum))) return CRE;
+               if (!Read32_64(fp,&(AEDR->DataType))) return CRE;
+               if (!Read32_64(fp,&(AEDR->Num))) return CRE;
+               if (!Read32_64(fp,&(AEDR->NumElems))) return CRE;
+               if (!Read32_64(fp,&(AEDR->rfuA))) return CRE;
+               if (!Read32_64(fp,&(AEDR->rfuB))) return CRE;
+               if (!Read32_64(fp,&(AEDR->rfuC))) return CRE;
+               if (!Read32_64(fp,&(AEDR->rfuD))) return CRE;
+               if (!Read32_64(fp,&(AEDR->rfuE))) return CRE;
+             */
              if (value != NULL) {
                nBytes = (size_t) (CDFelemSize(AEDR->DataType) * AEDR->NumElems);
                if (!READv64(value,nBytes,1,fp)) return CRE;
@@ -1099,17 +1151,26 @@ va_dcl
 	 if (!Read64_64(fp,&(VDR->RecordSize))) return CRE;
 	 if (!Read32_64(fp,&(VDR->RecordType))) return CRE;
 	 if (!Read64_64(fp,&(VDR->VDRnext))) return CRE;
-	 if (!Read32_64(fp,&(VDR->DataType))) return CRE;
-	 if (!Read32_64(fp,&(VDR->MaxRec))) return CRE;
-	 if (!Read64_64(fp,&(VDR->VXRhead))) return CRE;
-	 if (!Read64_64(fp,&(VDR->VXRtail))) return CRE;
-	 if (!Read32_64(fp,&(VDR->Flags))) return CRE;
-	 if (!Read32_64(fp,&(VDR->sRecords))) return CRE;
-	 if (!Read32_64(fp,&(VDR->rfuB))) return CRE;
-	 if (!Read32_64(fp,&(VDR->rfuC))) return CRE;
-	 if (!Read32_64(fp,&(VDR->rfuF))) return CRE;
-	 if (!Read32_64(fp,&(VDR->NumElems))) return CRE;
-	 if (!Read32_64(fp,&(VDR->Num))) return CRE;
+         if (!Read32s_64(fp,&(VDR->DataType),2)) return CRE;
+         /*
+	   if (!Read32_64(fp,&(VDR->DataType))) return CRE;
+	   if (!Read32_64(fp,&(VDR->MaxRec))) return CRE;
+         */
+         if (!Read64s_64(fp,&(VDR->VXRhead),2)) return CRE;
+         /*
+	   if (!Read64_64(fp,&(VDR->VXRhead))) return CRE;
+	   if (!Read64_64(fp,&(VDR->VXRtail))) return CRE;
+         */
+         if (!Read32s_64(fp,&(VDR->Flags),7)) return CRE;
+         /*
+	   if (!Read32_64(fp,&(VDR->Flags))) return CRE;
+	   if (!Read32_64(fp,&(VDR->sRecords))) return CRE;
+	   if (!Read32_64(fp,&(VDR->rfuB))) return CRE;
+	   if (!Read32_64(fp,&(VDR->rfuC))) return CRE;
+	   if (!Read32_64(fp,&(VDR->rfuF))) return CRE;
+	   if (!Read32_64(fp,&(VDR->NumElems))) return CRE;
+	   if (!Read32_64(fp,&(VDR->Num))) return CRE;
+         */
 	 if (!Read64_64(fp,&(VDR->CPRorSPRoffset))) return CRE;
 	 if (!Read32_64(fp,&(VDR->blockingFactor))) return CRE;
 	 if (!READv64(VDR->Name,CDF_VAR_NAME_LEN256,1,fp)) return CRE;
@@ -1309,8 +1370,11 @@ va_dcl
 	 if (!Read64_64(fp,&(VXR->RecordSize))) return CRE;
 	 if (!Read32_64(fp,&(VXR->RecordType))) return CRE;
 	 if (!Read64_64(fp,&(VXR->VXRnext))) return CRE;
-	 if (!Read32_64(fp,&(VXR->Nentries))) return CRE;
-	 if (!Read32_64(fp,&(VXR->NusedEntries))) return CRE;
+         if (!Read32s_64(fp,&(VXR->Nentries),2)) return CRE;
+         /*
+	   if (!Read32_64(fp,&(VXR->Nentries))) return CRE;
+	   if (!Read32_64(fp,&(VXR->NusedEntries))) return CRE;
+         */
          if ((int)VXR->Nentries < 0 || (int)VXR->Nentries > MAX_VXR_ENTRIES)
            return CV3C;
 	 if (!Read32s_64(fp,VXR->First,(int)VXR->Nentries)) return CRE;
@@ -1462,8 +1526,11 @@ va_dcl
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	 if (!Read64_64(fp,&(UIR->RecordSize))) return CRE;
 	 if (!Read32_64(fp,&(UIR->RecordType))) return CRE;
-	 if (!Read64_64(fp,&(UIR->NextUIR))) return CRE;
-	 if (!Read64_64(fp,&(UIR->PrevUIR))) return CRE;
+         if (!Read64s_64(fp,&(UIR->NextUIR),2)) return CRE;
+         /*
+	   if (!Read64_64(fp,&(UIR->NextUIR))) return CRE;
+	   if (!Read64_64(fp,&(UIR->PrevUIR))) return CRE;
+         */
 	 break;
        }
        case UIR_RECORDTYPE: {
@@ -1520,8 +1587,11 @@ va_dcl
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	 if (!Read64_64(fp,&(CCR->RecordSize))) return CRE;
 	 if (!Read32_64(fp,&(CCR->RecordType))) return CRE;
-	 if (!Read64_64(fp,&(CCR->CPRoffset))) return CRE;
-	 if (!Read64_64(fp,&(CCR->uSize))) return CRE;
+         if (!Read64s_64(fp,&(CCR->CPRoffset),2)) return CRE;
+         /*
+	   if (!Read64_64(fp,&(CCR->CPRoffset))) return CRE;
+	   if (!Read64_64(fp,&(CCR->uSize))) return CRE;
+         */
 	 if (!Read32_64(fp,&(CCR->rfuA))) return CRE;
 	 break;
        }
@@ -1583,10 +1653,13 @@ va_dcl
 	 struct CPRstruct64 *CPR = va_arg (ap, struct CPRstruct64 *); int i;
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	 if (!Read64_64(fp,&(CPR->RecordSize))) return CRE;
-	 if (!Read32_64(fp,&(CPR->RecordType))) return CRE;
-	 if (!Read32_64(fp,&(CPR->cType))) return CRE;
-	 if (!Read32_64(fp,&(CPR->rfuA))) return CRE;
-	 if (!Read32_64(fp,&(CPR->pCount))) return CRE;
+         if (!Read32s_64(fp,&(CPR->RecordType),4)) return CRE;
+         /*
+	   if (!Read32_64(fp,&(CPR->RecordType))) return CRE;
+	   if (!Read32_64(fp,&(CPR->cType))) return CRE;
+	   if (!Read32_64(fp,&(CPR->rfuA))) return CRE;
+	   if (!Read32_64(fp,&(CPR->pCount))) return CRE;
+         */
 	 if (CPR->pCount > CDF_MAX_PARMS) return TOO_MANY_PARMS;
 	 for (i = 0; i < CPR->pCount; i++) {
 	    if (!Read32_64(fp,&(CPR->cParms[i]))) return CRE;
@@ -1652,10 +1725,13 @@ va_dcl
 	 struct SPRstruct64 *SPR = va_arg (ap, struct SPRstruct64 *); int i;
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	 if (!Read64_64(fp,&(SPR->RecordSize))) return CRE;
-	 if (!Read32_64(fp,&(SPR->RecordType))) return CRE;
-	 if (!Read32_64(fp,&(SPR->sArraysType))) return CRE;
-	 if (!Read32_64(fp,&(SPR->rfuA))) return CRE;
-	 if (!Read32_64(fp,&(SPR->pCount))) return CRE;
+         if (!Read32s_64(fp,&(SPR->RecordType),4)) return CRE;
+         /*
+	   if (!Read32_64(fp,&(SPR->RecordType))) return CRE;
+	   if (!Read32_64(fp,&(SPR->sArraysType))) return CRE;
+	   if (!Read32_64(fp,&(SPR->rfuA))) return CRE;
+	   if (!Read32_64(fp,&(SPR->pCount))) return CRE;
+         */
 	 if (SPR->pCount > CDF_MAX_PARMS) return TOO_MANY_PARMS;
 	 for (i = 0; i < SPR->pCount; i++) {
 	    if (!Read32_64(fp,&(SPR->sArraysParms[i]))) return CRE;
@@ -1721,8 +1797,11 @@ va_dcl
 	 struct CVVRstruct64 *CVVR = va_arg (ap, struct CVVRstruct64 *);
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CRE;
 	 if (!Read64_64(fp,&(CVVR->RecordSize))) return CRE;
-	 if (!Read32_64(fp,&(CVVR->RecordType))) return CRE;
-	 if (!Read32_64(fp,&(CVVR->rfuA))) return CRE;
+         if (!Read32s_64(fp,&(CVVR->RecordType),2)) return CRE;
+         /*
+	   if (!Read32_64(fp,&(CVVR->RecordType))) return CRE;
+	   if (!Read32_64(fp,&(CVVR->rfuA))) return CRE;
+         */
 	 if (!Read64_64(fp,&(CVVR->cSize))) return CRE;
 	 break;
        }
@@ -1741,10 +1820,10 @@ va_dcl
        default: {
 	 Int32 *buffer = va_arg (ap, Int32 *); OFF_T tOffset = offset;
 	 switch (field) {
-/*	   case CVVR_RECORDSIZE: tOffset += (OFF_T) CVVR_RECORDSIZE_OFFSET64; break; */
+           /* case CVVR_RECORDSIZE: tOffset += (OFF_T) CVVR_RECORDSIZE_OFFSET64; break; */
 	   case CVVR_RECORDTYPE: tOffset += (OFF_T) CVVR_RECORDTYPE_OFFSET64; break;
 	   case CVVR_RFUa: tOffset += (OFF_T) CVVR_RFUa_OFFSET64; break;
-/*	   case CVVR_CSIZE: tOffset += (OFF_T) CVVR_CSIZE_OFFSET64; break; */
+           /* case CVVR_CSIZE: tOffset += (OFF_T) CVVR_CSIZE_OFFSET64; break; */
 	   default: return CDF_INTERNAL_ERROR;
 	 }
 	 if (!SEEKv64(fp,tOffset,vSEEK_SET)) return CRE;
@@ -1792,16 +1871,22 @@ STATICforIDL CDFstatus ReadADRList64 (vFILE *fp)
       fp->ADRList64[i]->ADRnext = 0;
       if (!Read64_64(fp,&temp)) return CRE;
       fp->ADRList64[i]->AgrEDRhead = temp;
+      if (!Read32s_64(fp,&(fp->ADRList64[i]->Scope),5)) return CRE;
+      /*
       if (!Read32_64(fp,&(fp->ADRList64[i]->Scope))) return CRE;
       if (!Read32_64(fp,&(fp->ADRList64[i]->Num))) return CRE;
       if (!Read32_64(fp,&(fp->ADRList64[i]->NgrEntries))) return CRE;
       if (!Read32_64(fp,&(fp->ADRList64[i]->MAXgrEntry))) return CRE;
       if (!Read32_64(fp,&(fp->ADRList64[i]->rfuA))) return CRE;
+      */
       if (!Read64_64(fp,&temp)) return CRE;
       fp->ADRList64[i]->AzEDRhead = temp;
-      if (!Read32_64(fp,&(fp->ADRList64[i]->NzEntries))) return CRE;
-      if (!Read32_64(fp,&(fp->ADRList64[i]->MAXzEntry))) return CRE;
-      if (!Read32_64(fp,&(fp->ADRList64[i]->rfuE))) return CRE;
+      if (!Read32s_64(fp,&(fp->ADRList64[i]->NzEntries),3)) return CRE;
+      /*
+        if (!Read32_64(fp,&(fp->ADRList64[i]->NzEntries))) return CRE;
+        if (!Read32_64(fp,&(fp->ADRList64[i]->MAXzEntry))) return CRE;
+        if (!Read32_64(fp,&(fp->ADRList64[i]->rfuE))) return CRE;
+      */
       if (!READv64(fp->ADRList64[i]->Name,CDF_ATTR_NAME_LEN256,1,fp))
         return CRE;
       NulPad (fp->ADRList64[i]->Name, CDF_ATTR_NAME_LEN256);
@@ -1876,15 +1961,18 @@ STATICforIDL CDFstatus ReadAEDRList64 (vFILE *fp,
       if (!Read64_64(fp,&temp)) return CRE;
       NxtAEDR = temp;
       TempAEDR->AEDR.AEDRnext = 0;
-      if (!Read32_64(fp,&(TempAEDR->AEDR.AttrNum))) return CRE;
-      if (!Read32_64(fp,&(TempAEDR->AEDR.DataType))) return CRE;
-      if (!Read32_64(fp,&(TempAEDR->AEDR.Num))) return CRE;
-      if (!Read32_64(fp,&(TempAEDR->AEDR.NumElems))) return CRE;
-      if (!Read32_64(fp,&(TempAEDR->AEDR.rfuA))) return CRE;
-      if (!Read32_64(fp,&(TempAEDR->AEDR.rfuB))) return CRE;
-      if (!Read32_64(fp,&(TempAEDR->AEDR.rfuC))) return CRE;
-      if (!Read32_64(fp,&(TempAEDR->AEDR.rfuD))) return CRE;
-      if (!Read32_64(fp,&(TempAEDR->AEDR.rfuE))) return CRE;
+      if (!Read32s_64(fp,&(TempAEDR->AEDR.AttrNum),9)) return CRE;
+      /*
+        if (!Read32_64(fp,&(TempAEDR->AEDR.AttrNum))) return CRE;
+        if (!Read32_64(fp,&(TempAEDR->AEDR.DataType))) return CRE;
+        if (!Read32_64(fp,&(TempAEDR->AEDR.Num))) return CRE;
+        if (!Read32_64(fp,&(TempAEDR->AEDR.NumElems))) return CRE;
+        if (!Read32_64(fp,&(TempAEDR->AEDR.rfuA))) return CRE;
+        if (!Read32_64(fp,&(TempAEDR->AEDR.rfuB))) return CRE;
+        if (!Read32_64(fp,&(TempAEDR->AEDR.rfuC))) return CRE;
+        if (!Read32_64(fp,&(TempAEDR->AEDR.rfuD))) return CRE;
+        if (!Read32_64(fp,&(TempAEDR->AEDR.rfuE))) return CRE;
+      */
       TempAEDR->ValueSize = (CDFelemSize(TempAEDR->AEDR.DataType) * 
                              TempAEDR->AEDR.NumElems);
       if (TempAEDR->ValueSize < 1) {
