@@ -40,7 +40,7 @@ char *copyRight;
   strcpyX (copyRight,
 "\012\
 Common Data Format (CDF)\012\
-(C) Copyright 1990-2014 NASA/GSFC\012\
+(C) Copyright 1990-2015 NASA/GSFC\012\
 Space Physics Data Facility\012\
 NASA/Goddard Space Flight Center\012\
 Greenbelt, Maryland 20771 USA\012\
@@ -779,6 +779,24 @@ strcpyX (textPtr,
 CDF_STATUSTEXT_LEN);
 break;
 
+case TT2000_CDF_MAYNEEDUPDATE:
+strcpyX (textPtr,
+"TT2000_CDF_MAYNEEDUPDATE: CDF may need update as a TT2000 data value was not made with the latest CDF version (even its value may be valid).",
+CDF_STATUSTEXT_LEN);
+break;
+
+case TT2000_USED_OUTDATED_TABLE:
+strcpyX (textPtr,
+"TT2000_USED_OUTDATED_TABLE: A TT2000 data is either invalid (made with an oudated leap second table) or trying to use an outdated leap second table.",
+CDF_STATUSTEXT_LEN);
+break;
+
+case BADDATE_LEAPSECOND_UPDATED:
+strcpyX (textPtr,
+"BADDATE_LEAPSECOND_UPDATED: The last leap second updated date is not valid (not in the leap second table).",
+CDF_STATUSTEXT_LEN);
+break;
+
 default:
 snprintf (textPtr, (size_t) CDF_STATUSTEXT_LEN+1,
           "Text not found - unknown CDF status code (%ld).", status);
