@@ -56,6 +56,70 @@ static struct GDRstruct GDR;
 static int rVars, zVars;
 static int numAttrs;
 
+/******************************************************************************
+* QuitCDF.
+******************************************************************************/
+
+static CDFstatus QuitCDF (char *why, Int32 offset, int size, int num,
+	                  void *value1, void *value2, Logical debug)
+{
+  
+  if (debug) {
+    char text[151], texta[41];
+    text[0] = NUL;
+    strcpyX (text, why, 150);
+    if (offset >= 0) {
+      snprintf (texta, (size_t) sizeof(texta),
+                " (@%ld) ", (long) offset);
+      strcatX (text, texta, 150);
+    }
+    if (strlen(why) < 150) {
+      if (num == 2) { /* Two argument values to show. */
+        if (size == 4) { /* Each one is a 4-byte int type. */
+                         /* Each int is up to 10 digits + sign. */
+          char text2[2 * 11 + 6 + 1];
+          text2[0] = NUL;
+          snprintf (text2, (size_t) sizeof(text2),
+		    "(%ld vs %ld)", (long) *(int *)value1,
+                    (long) *(int *)value2);
+          strcatX (text, text2, 150);
+        } else { /* Both are strings. */
+          char *text2;
+          size_t len = strlen ((char *) value1) + strlen ((char *) value2) + 
+                       6 + 1;
+          text2 = (char *) cdf_AllocateMemory (len, NULL);
+          if (text2 != NULL) {
+            text2[0] = NUL;
+            snprintf (text2, len, "(%s vs %s)", (char *)value1, (char *)value2);
+            strcatX (text, text2, 150);
+            cdf_FreeMemory (text2, NULL);
+          }
+        }
+      } else { /* Only one argument value to show. */
+        if (size == 4) { /* Each int is up to 10 digits + sign. */
+          char text2[11 + 2 + 1];
+          text2[0] = NUL;
+          snprintf (text2, (size_t) sizeof(text2),
+		    "(%ld)", (long) *(int *)value1);
+          strcatX (text, text2, 150);
+        } else {
+          char *text2;
+          size_t len = strlen ((char *) value1) + 2 + 1;
+          text2 = (char *) cdf_AllocateMemory (len, NULL);
+          if (text2 != NULL) {
+            text2[0] = NUL;
+            snprintf (text2, len, "(%s)", (char *)value1);
+            strcatX (text, text2, 150);
+            cdf_FreeMemory (text2, NULL);
+          }
+        }
+      }
+    }
+    printf ("ERROR...%s\n", text);
+  }
+  return CV2C;
+}
+
 /******************************************************************************
 * ValidateCDF.
 *   Start to validate each internal record in a CDF file.
@@ -265,7 +329,7 @@ STATICforIDL CDFstatus ValidateCDF (struct CDFstruct *CDF, vFILE *CDFfp,
 * ValidateCDR.
 ******************************************************************************/
 
-CDFstatus ValidateCDR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateCDR (vFILE *fp, Int32 offset, Logical debug)
 {
   Int32 actualEncoding;
 /*
@@ -291,9 +355,15 @@ CDFstatus ValidateCDR (vFILE *fp, Int32 offset, Logical debug)
   if (CDR.GDRoffset < 1) 
     return QuitCDF ("CDF(CDR): offset to GDR is invalid ", offset,
                     4, 1, &(CDR.GDRoffset), 0, debug);
-  if (CDR.Version != 2) 
-    return QuitCDF ("CDF(CDR): version number is invalid ", offset,
+  if (CDR.Version != 2)
+    return QuitCDF ("CDF: version number is invalid ", offset,
                     4, 1, &(CDR.Version), 0, debug);
+  if (CDR.Release < 0)
+    return QuitCDF ("CDF: release number is invalid ", offset,
+                    4, 1, &(CDR.Release), 0, debug);
+  if (CDR.Increment < 0)
+    return QuitCDF ("CDF: increment number is invalid ", offset,
+                    4, 1, &(CDR.Increment), 0, debug);
   if (!ValidEncoding(CDR.Encoding,&actualEncoding)) 
     return QuitCDF ("CDF(CDR): encoding is invalid ", offset,
                     4, 1, &(CDR.Encoding), 0, debug);
@@ -310,7 +380,7 @@ CDFstatus ValidateCDR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateGDR.
 ******************************************************************************/
 
-CDFstatus ValidateGDR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateGDR (vFILE *fp, Int32 offset, Logical debug)
 {
   int i;
   CDFstatus status;
@@ -358,8 +428,8 @@ CDFstatus ValidateGDR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateADR.
 ******************************************************************************/
 
-CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, Int32 offset, 
-                       Logical debug)
+static CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, Int32 offset, 
+                              Logical debug)
 {
   struct ADRstruct ADR;
   CDFstatus status;
@@ -435,9 +505,9 @@ CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
 * ValidateAEDR/AzEDR.
 ******************************************************************************/
 
-CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
-                        Int32 num, Int32 maxEntry, Logical zEntry, 
-                        Logical debug)
+static CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
+                               Int32 num, Int32 maxEntry, Logical zEntry, 
+                               Logical debug)
 {
   struct AEDRstruct AEDR;
   size_t nBytes;
@@ -501,8 +571,8 @@ CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
 * ValidateVDR/zVDR.
 ******************************************************************************/
 
-CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset, 
-		       Logical zVar, Logical debug)
+static CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset, 
+		              Logical zVar, Logical debug)
 {
   struct VDRstruct VDR;
   void *padValue;
@@ -573,7 +643,8 @@ CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, Int32 offset,
 * ValidateVXR.
 ******************************************************************************/
 
-CDFstatus ValidateVXR (vFILE *fp, Int32 offset, Int32 lastRec, Logical debug)
+static CDFstatus ValidateVXR (vFILE *fp, Int32 offset, Int32 lastRec,
+	                      Logical debug)
 {
   struct VXRstruct VXR;
   int i;
@@ -634,7 +705,7 @@ CDFstatus ValidateVXR (vFILE *fp, Int32 offset, Int32 lastRec, Logical debug)
 * ValidateVVR.
 ******************************************************************************/
 
-CDFstatus ValidateVVR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateVVR (vFILE *fp, Int32 offset, Logical debug)
 {
   struct VVRstruct VVR;
   CDFstatus status;
@@ -658,7 +729,7 @@ CDFstatus ValidateVVR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateUIR.
 ******************************************************************************/
 
-CDFstatus ValidateUIR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateUIR (vFILE *fp, Int32 offset, Logical debug)
 {
   struct UIRstruct UIR;
   CDFstatus status;
@@ -688,7 +759,7 @@ CDFstatus ValidateUIR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateCCR.
 ******************************************************************************/
 
-CDFstatus ValidateCCR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateCCR (vFILE *fp, Int32 offset, Logical debug)
 {
   struct CCRstruct CCR;
   CDFstatus status;
@@ -718,7 +789,7 @@ CDFstatus ValidateCCR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateCPR.
 ******************************************************************************/
 
-CDFstatus ValidateCPR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateCPR (vFILE *fp, Int32 offset, Logical debug)
 {
   struct CPRstruct CPR;
   int i;
@@ -752,7 +823,7 @@ CDFstatus ValidateCPR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateSPR.
 ******************************************************************************/
 
-CDFstatus ValidateSPR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateSPR (vFILE *fp, Int32 offset, Logical debug)
 {
   struct SPRstruct SPR;
   CDFstatus status;
@@ -779,7 +850,7 @@ CDFstatus ValidateSPR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateCVVR.
 ******************************************************************************/
 
-CDFstatus ValidateCVVR (vFILE *fp, Int32 offset, Logical debug)
+static CDFstatus ValidateCVVR (vFILE *fp, Int32 offset, Logical debug)
 {
   struct CVVRstruct CVVR;
   CDFstatus status;
@@ -803,8 +874,8 @@ CDFstatus ValidateCVVR (vFILE *fp, Int32 offset, Logical debug)
 * ValidateAttributeLinks.
 ******************************************************************************/
 
-CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp, 
-                                  Logical debug)
+static CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp, 
+                                         Logical debug)
 {
   CDFstatus status;
   Int32 offset, nextADR, AgrEDRhead, AzEDRhead;
@@ -862,10 +933,10 @@ CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
 * ValidateAttributeEntryLink.
 ******************************************************************************/
 
-CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp, 
+static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp, 
                                       Int32 num, Logical zEntry, Int32 EDRhead, 
-                                      Int32 numEntries, Int32 maxEntry,
-                                      Logical debug)
+                                             Int32 numEntries, Int32 maxEntry,
+                                             Logical debug)
 {
   CDFstatus status;
   Int32 offset, nextAEDR;
@@ -920,8 +991,8 @@ CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
 * ValidateVariableLinks.
 ******************************************************************************/
 
-CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp, 
-                                 Logical zVar, Logical debug)
+static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp, 
+                                        Logical zVar, Logical debug)
 {
   CDFstatus status;
   Int32 offset, headVXR, tailVXR, nextVDR, cprOffset;
@@ -1003,9 +1074,9 @@ CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
 * ValidateVariableValueLinks.
 ******************************************************************************/
 
-CDFstatus ValidateVariableValueLinks (struct CDFstruct *CDF, vFILE *fp, 
-                                      Int32 lastRec, Int32 headVXR,
-                                      Logical debug)
+static CDFstatus ValidateVariableValueLinks (struct CDFstruct *CDF, vFILE *fp, 
+                                             Int32 lastRec, Int32 headVXR,
+                                             Logical debug)
 {
   CDFstatus status;
 
@@ -1015,67 +1086,3 @@ CDFstatus ValidateVariableValueLinks (struct CDFstruct *CDF, vFILE *fp,
   return CDF_OK;
 }
 
-/******************************************************************************
-* QuitCDF.
-******************************************************************************/
-
-CDFstatus QuitCDF (char *why, Int32 offset, int size, int num, void *value1,
-		   void *value2, Logical debug)
-{
-  
-  if (debug) {
-    char text[151], texta[41];
-    text[0] = NUL;
-    strcpyX (text, why, 150);
-    if (offset >= 0) {
-      snprintf (texta, (size_t) sizeof(texta),
-                " (@%ld) ", (long) offset);
-      strcatX (text, texta, 150);
-    }
-    if (strlen(why) < 150) {
-      if (num == 2) { /* Two argument values to show. */
-        if (size == 4) { /* Each one is a 4-byte int type. */
-                         /* Each int is up to 10 digits + sign. */
-          char text2[2 * 11 + 6 + 1];
-          text2[0] = NUL;
-          snprintf (text2, (size_t) sizeof(text2),
-		    "(%ld vs %ld)", (long) *(int *)value1,
-                    (long) *(int *)value2);
-          strcatX (text, text2, 150);
-        } else { /* Both are strings. */
-          char *text2;
-          size_t len = strlen ((char *) value1) + strlen ((char *) value2) + 
-                       6 + 1;
-          text2 = (char *) cdf_AllocateMemory (len, NULL);
-          if (text2 != NULL) {
-            text2[0] = NUL;
-            snprintf (text2, len, "(%s vs %s)", (char *)value1, (char *)value2);
-            strcatX (text, text2, 150);
-            cdf_FreeMemory (text2, NULL);
-          }
-        }
-      } else { /* Only one argument value to show. */
-        if (size == 4) { /* Each int is up to 10 digits + sign. */
-          char text2[11 + 2 + 1];
-          text2[0] = NUL;
-          snprintf (text2, (size_t) sizeof(text2),
-		    "(%ld)", (long) *(int *)value1);
-          strcatX (text, text2, 150);
-        } else {
-          char *text2;
-          size_t len = strlen ((char *) value1) + 2 + 1;
-          text2 = (char *) cdf_AllocateMemory (len, NULL);
-          if (text2 != NULL) {
-            text2[0] = NUL;
-            snprintf (text2, len, "(%s)", (char *)value1);
-            strcatX (text, text2, 150);
-            cdf_FreeMemory (text2, NULL);
-          }
-        }
-      }
-    }
-    printf ("ERROR...%s\n", text);
-  }
-  return CV2C;
-}
-
