@@ -54,6 +54,98 @@ static struct GDRstruct64 GDR;
 static int rVars, zVars;
 static int numAttrs;
 
+/******************************************************************************
+* QuitCDF.
+******************************************************************************/
+
+static CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num,
+			  void *value1,void *value2, Logical debug)
+{
+  
+  if (debug) {
+    char text[151], texta[41];
+    text[0] = NUL;
+    strcpyX (text, why, 150);
+    if (offset >= 0) {
+#if !defined(win32) && !defined(__MINGW32__)
+      snprintf (texta, (size_t) sizeof(texta),
+	        " (@%lld) ", offset);
+#else
+      snprintf (texta, (size_t) sizeof(texta),
+	        " (@%I64d) ", offset);
+#endif
+      strcatX (text, texta, 150);
+    }
+    if (strlen(why) < 150) {
+      if (num == 2) { /* Two argument values to show. */
+        if (isize == 4) { /* Each one is a 4-byte int type. */ 
+                          /* Each int is up to 10 digits + sign. */
+          char text2[2 * 11 + 6 + 1];
+          text2[0] = (char) NUL;
+          snprintf (text2, (size_t) sizeof(text2),
+		    "(%ld vs %ld)", (long) *(int *)value1,
+                    (long) *(int *)value2);
+          strcatX (text, text2, 150);
+        } else if (isize == 8) { /* Each one is a 8-byte long long type. */
+                                 /* Each long long is up to 19 digits + sign. */
+          char text2[2 * 20 + 6 + 1];
+          text2[0] = (char) NUL;
+#if !defined(win32) && !defined(__MINGW32__)
+          snprintf (text2, (size_t) sizeof(text2),
+		    "(%lld vs %lld)", *(OFF_T *)value1, *(OFF_T *)value2);
+#else
+          snprintf (text2, (size_t) sizeof(text2),
+		    "(%I64d vs %I64d)", *(OFF_T *)value1, *(OFF_T *)value2);
+#endif
+          strcatX (text, text2, 150);
+        } else { /* Each one is a string. */
+          char *text2;
+          size_t len = strlen ((char *) value1) + strlen ((char *) value2) + 6
+                       + 1;
+          text2 = (char *) cdf_AllocateMemory (len, NULL);
+          if (text2 != NULL) {
+            text2[0] = (char) NUL;
+            snprintf (text2, len, "(%s vs %s)", (char *)value1, (char *)value2);
+            strcatX (text, text2, 150);
+            cdf_FreeMemory (text2, NULL);
+          }
+        }
+      } else { /* Only one argument value to show. */
+        if (isize == 4) { /* 4 extra chars are for 2 " ", "(", and ")". */
+          char text2[11 + 2 + 1];
+          text2[0] = (char) NUL;
+          snprintf (text2, (size_t) sizeof(text2),
+		    "(%ld)", (long) *(int *)value1);
+          strcatX (text, text2, 150);
+        } else if (isize == 8) {
+          char text2[20 + 2 + 1];
+          text2[0] = (char) NUL;
+#if !defined(win32) && !defined(__MINGW32__)
+          snprintf (text2, (size_t) sizeof(text2),
+		    "(%lld)", *(OFF_T *)value1);
+#else
+          snprintf (text2, (size_t) sizeof(text2),
+		    "(%I64d)", *(OFF_T *)value1);
+#endif
+          strcatX (text, text2, 150);
+        } else {
+          char *text2;
+          size_t len = strlen ((char *) value1)  + 2 + 1;
+          text2 = (char *) cdf_AllocateMemory (len, NULL);
+          if (text2 != NULL) {
+            text2[0] = (char) NUL;
+            snprintf (text2, len, "(%s)", (char *)value1);
+            strcatX (text, text2, 150);
+            cdf_FreeMemory (text2, NULL);
+          }
+        }
+      }
+    }
+    printf ("ERROR...%s\n", text);
+  }
+  return CV3C;
+}
+
 /******************************************************************************
 * ValidateCDF64.
 *   Start to validate each internal record in a CDF file.
@@ -254,7 +346,7 @@ STATICforIDL CDFstatus ValidateCDF64 (struct CDFstruct *CDF, vFILE *CDFfp,
 * ValidateCDR.
 ******************************************************************************/
 
-CDFstatus ValidateCDR (vFILE *fp, OFF_T offset, Logical debug)
+static CDFstatus ValidateCDR (vFILE *fp, OFF_T offset, Logical debug)
 {
   Int32 actualEncoding;
   int i;
@@ -283,6 +375,12 @@ CDFstatus ValidateCDR (vFILE *fp, OFF_T offset, Logical debug)
   if (CDR.Version != 3) 
     return QuitCDF ("CDF: version number is invalid ", offset,
                     4, 1, &(CDR.Version), 0, debug);
+  if (CDR.Release < 0) 
+    return QuitCDF ("CDF: release number is invalid ", offset,
+                    4, 1, &(CDR.Release), 0, debug);
+  if (CDR.Increment < 0) 
+    return QuitCDF ("CDF: increment number is invalid ", offset,
+                    4, 1, &(CDR.Increment), 0, debug);
   if (!ValidEncoding(CDR.Encoding,&actualEncoding)) 
     return QuitCDF ("CDF: encoding is invalid ", offset,
                     4, 1, &(CDR.Encoding), 0, debug);
@@ -293,7 +391,7 @@ CDFstatus ValidateCDR (vFILE *fp, OFF_T offset, Logical debug)
 * ValidateGDR.
 ******************************************************************************/
 
-CDFstatus ValidateGDR (vFILE *fp, OFF_T offset, Logical debug)
+static CDFstatus ValidateGDR (vFILE *fp, OFF_T offset, Logical debug)
 {
   int i;
   CDFstatus status;
@@ -344,8 +442,8 @@ CDFstatus ValidateGDR (vFILE *fp, OFF_T offset, Logical debug)
 * ValidateADR.
 ******************************************************************************/
 
-CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset, 
-                       Logical debug)
+static CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset, 
+                              Logical debug)
 {
   struct ADRstruct64 ADR;
   CDFstatus status;
@@ -404,9 +502,9 @@ CDFstatus ValidateADR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
 * ValidateAgrEDR/AzEDR.
 ******************************************************************************/
 
-CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
-                        Int32 num, Int32 maxEntry, Logical zEntry, 
-                        Logical debug)
+static CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
+                               Int32 num, Int32 maxEntry, Logical zEntry, 
+                               Logical debug)
 {
   struct AEDRstruct64 AEDR;
   size_t nBytes;
@@ -468,8 +566,8 @@ CDFstatus ValidateAEDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
 * ValidateVDR/zVDR.
 ******************************************************************************/
 
-CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset, 
-		       Logical zVar, Logical debug)
+static CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset, 
+		              Logical zVar, Logical debug)
 {
   struct VDRstruct64 VDR;
   void *padValue;
@@ -543,7 +641,7 @@ CDFstatus ValidateVDR (struct CDFstruct *CDF, vFILE *fp, OFF_T offset,
 * ValidateVXR.
 ******************************************************************************/
 
-CDFstatus ValidateVXR (vFILE *fp, OFF_T offset, Int32 lastRec, Logical debug)
+static CDFstatus ValidateVXR (vFILE *fp, OFF_T offset, Int32 lastRec, Logical debug)
 {
   struct VXRstruct64 VXR;
   int i;
@@ -607,7 +705,7 @@ CDFstatus ValidateVXR (vFILE *fp, OFF_T offset, Int32 lastRec, Logical debug)
 * ValidateVVR.
 ******************************************************************************/
 
-CDFstatus ValidateVVR (vFILE *fp, OFF_T offset, Logical debug)
+static CDFstatus ValidateVVR (vFILE *fp, OFF_T offset, Logical debug)
 {
   struct VVRstruct64 VVR;
   CDFstatus status;
@@ -635,7 +733,7 @@ CDFstatus ValidateVVR (vFILE *fp, OFF_T offset, Logical debug)
 * ValidateUIR.
 ******************************************************************************/
 
-CDFstatus ValidateUIR (vFILE *fp, OFF_T offset, Logical debug)
+static CDFstatus ValidateUIR (vFILE *fp, OFF_T offset, Logical debug)
 {
   struct UIRstruct64 UIR;
   CDFstatus status;
@@ -669,7 +767,7 @@ CDFstatus ValidateUIR (vFILE *fp, OFF_T offset, Logical debug)
 * ValidateCCR.
 ******************************************************************************/
 
-CDFstatus ValidateCCR (vFILE *fp, OFF_T offset, Logical debug)
+static CDFstatus ValidateCCR (vFILE *fp, OFF_T offset, Logical debug)
 {
   struct CCRstruct64 CCR;
   CDFstatus status;
@@ -703,7 +801,7 @@ CDFstatus ValidateCCR (vFILE *fp, OFF_T offset, Logical debug)
 * ValidateCPR.
 ******************************************************************************/
 
-CDFstatus ValidateCPR (vFILE *fp, OFF_T offset, Logical debug)
+static CDFstatus ValidateCPR (vFILE *fp, OFF_T offset, Logical debug)
 {
   struct CPRstruct64 CPR;
   int i;
@@ -741,7 +839,7 @@ CDFstatus ValidateCPR (vFILE *fp, OFF_T offset, Logical debug)
 * ValidateSPR.
 ******************************************************************************/
 
-CDFstatus ValidateSPR (vFILE *fp, OFF_T offset, Logical debug)
+static CDFstatus ValidateSPR (vFILE *fp, OFF_T offset, Logical debug)
 {
   struct SPRstruct64 SPR;
   int i;
@@ -773,7 +871,7 @@ CDFstatus ValidateSPR (vFILE *fp, OFF_T offset, Logical debug)
 * ValidateCVVR.
 ******************************************************************************/
 
-CDFstatus ValidateCVVR (vFILE *fp, OFF_T offset, Logical debug)
+static CDFstatus ValidateCVVR (vFILE *fp, OFF_T offset, Logical debug)
 {
   struct CVVRstruct64 CVVR;
   CDFstatus status;
@@ -801,8 +899,8 @@ CDFstatus ValidateCVVR (vFILE *fp, OFF_T offset, Logical debug)
 * ValidateAttributeLinks.
 ******************************************************************************/
 
-CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp, 
-                                  Logical debug)
+static CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp, 
+                                         Logical debug)
 {
   CDFstatus status;
   OFF_T offset, nextADR, AgrEDRhead, AzEDRhead;
@@ -863,10 +961,10 @@ CDFstatus ValidateAttributeLinks (struct CDFstruct *CDF, vFILE *fp,
 * ValidateAttributeEntryLink.
 ******************************************************************************/
 
-CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp, 
+static CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp, 
                                       Int32 num, Logical zEntry, OFF_T EDRhead,
-                                      Int32 numEntries, Int32 maxEntry, 
-                                      Logical debug)
+                                             Int32 numEntries, Int32 maxEntry, 
+                                             Logical debug)
 {
   CDFstatus status;
   OFF_T offset, nextAEDR;
@@ -921,8 +1019,8 @@ CDFstatus ValidateAttributeEntryLink (struct CDFstruct *CDF, vFILE *fp,
 * ValidateVariableLinks.
 ******************************************************************************/
 
-CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp, 
-                                 Logical zVar, Logical debug)
+static CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp, 
+                                        Logical zVar, Logical debug)
 {
   CDFstatus status;
   OFF_T offset, headVXR, tailVXR, nextVXR, nextVDR, cprOffset;
@@ -1008,9 +1106,9 @@ CDFstatus ValidateVariableLinks (struct CDFstruct *CDF, vFILE *fp,
 * ValidateVariableValueLinks.
 ******************************************************************************/
 
-CDFstatus ValidateVariableValueLinks (struct CDFstruct *CDF, vFILE *fp,
-                                      Int32 lastRec, OFF_T headVXR,
-                                      Logical debug)
+static CDFstatus ValidateVariableValueLinks (struct CDFstruct *CDF, vFILE *fp,
+                                             Int32 lastRec, OFF_T headVXR,
+                                             Logical debug)
 {
   CDFstatus status;
 
@@ -1019,95 +1117,3 @@ CDFstatus ValidateVariableValueLinks (struct CDFstruct *CDF, vFILE *fp,
   return CDF_OK;
 }
 
-/******************************************************************************
-* QuitCDF.
-******************************************************************************/
-
-CDFstatus QuitCDF (char *why, OFF_T offset, int isize, int num, void *value1,
-		   void *value2, Logical debug)
-{
-  
-  if (debug) {
-    char text[151], texta[41];
-    text[0] = NUL;
-    strcpyX (text, why, 150);
-    if (offset >= 0) {
-#if !defined(win32) && !defined(__MINGW32__)
-      snprintf (texta, (size_t) sizeof(texta),
-	        " (@%lld) ", offset);
-#else
-      snprintf (texta, (size_t) sizeof(texta),
-	        " (@%I64d) ", offset);
-#endif
-      strcatX (text, texta, 150);
-    }
-    if (strlen(why) < 150) {
-      if (num == 2) { /* Two argument values to show. */
-        if (isize == 4) { /* Each one is a 4-byte int type. */ 
-                          /* Each int is up to 10 digits + sign. */
-          char text2[2 * 11 + 6 + 1];
-          text2[0] = (char) NUL;
-          snprintf (text2, (size_t) sizeof(text2),
-		    "(%ld vs %ld)", (long) *(int *)value1,
-                    (long) *(int *)value2);
-          strcatX (text, text2, 150);
-        } else if (isize == 8) { /* Each one is a 8-byte long long type. */
-                                 /* Each long long is up to 19 digits + sign. */
-          char text2[2 * 20 + 6 + 1];
-          text2[0] = (char) NUL;
-#if !defined(win32) && !defined(__MINGW32__)
-          snprintf (text2, (size_t) sizeof(text2),
-		    "(%lld vs %lld)", *(OFF_T *)value1, *(OFF_T *)value2);
-#else
-          snprintf (text2, (size_t) sizeof(text2),
-		    "(%I64d vs %I64d)", *(OFF_T *)value1, *(OFF_T *)value2);
-#endif
-          strcatX (text, text2, 150);
-        } else { /* Each one is a string. */
-          char *text2;
-          size_t len = strlen ((char *) value1) + strlen ((char *) value2) + 6
-                       + 1;
-          text2 = (char *) cdf_AllocateMemory (len, NULL);
-          if (text2 != NULL) {
-            text2[0] = (char) NUL;
-            snprintf (text2, len, "(%s vs %s)", (char *)value1, (char *)value2);
-            strcatX (text, text2, 150);
-            cdf_FreeMemory (text2, NULL);
-          }
-        }
-      } else { /* Only one argument value to show. */
-        if (isize == 4) { /* 4 extra chars are for 2 " ", "(", and ")". */
-          char text2[11 + 2 + 1];
-          text2[0] = (char) NUL;
-          snprintf (text2, (size_t) sizeof(text2),
-		    "(%ld)", (long) *(int *)value1);
-          strcatX (text, text2, 150);
-        } else if (isize == 8) {
-          char text2[20 + 2 + 1];
-          text2[0] = (char) NUL;
-#if !defined(win32) && !defined(__MINGW32__)
-          snprintf (text2, (size_t) sizeof(text2),
-		    "(%lld)", *(OFF_T *)value1);
-#else
-          snprintf (text2, (size_t) sizeof(text2),
-		    "(%I64d)", *(OFF_T *)value1);
-#endif
-          strcatX (text, text2, 150);
-        } else {
-          char *text2;
-          size_t len = strlen ((char *) value1)  + 2 + 1;
-          text2 = (char *) cdf_AllocateMemory (len, NULL);
-          if (text2 != NULL) {
-            text2[0] = (char) NUL;
-            snprintf (text2, len, "(%s)", (char *)value1);
-            strcatX (text, text2, 150);
-            cdf_FreeMemory (text2, NULL);
-          }
-        }
-      }
-    }
-    printf ("ERROR...%s\n", text);
-  }
-  return CV3C;
-}
-
