@@ -196,6 +196,8 @@ va_dcl
 	 if (!Write64_64(fp,&(CDR->RecordSize))) return CWE;
 	 if (!Write32_64(fp,&(CDR->RecordType))) return CWE;
 	 if (!Write64_64(fp,&(CDR->GDRoffset))) return CWE;
+         if (!Write32s_64(fp,&(CDR->Version),9)) return CWE;
+/*
 	 if (!Write32_64(fp,&(CDR->Version))) return CWE;
 	 if (!Write32_64(fp,&(CDR->Release))) return CWE;
 	 if (!Write32_64(fp,&(CDR->Encoding))) return CWE;
@@ -205,6 +207,7 @@ va_dcl
 	 if (!Write32_64(fp,&(CDR->Increment))) return CWE;
 	 if (!Write32_64(fp,&(CDR->rfuD))) return CWE;
 	 if (!Write32_64(fp,&(CDR->rfuE))) return CWE;
+*/
 	 if (copyRight != NULL) {
 	   if (!WRITEv64(copyRight,CDF_COPYRIGHT_LEN,1,fp)) return CWE;
 	 }
@@ -281,19 +284,28 @@ va_dcl
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CWE;
 	 if (!Write64_64(fp,&(GDR->RecordSize))) return CWE;
 	 if (!Write32_64(fp,&(GDR->RecordType))) return CWE;
+         if (!Write64s_64(fp,&(GDR->rVDRhead),4)) return CWE;
+/*
 	 if (!Write64_64(fp,&(GDR->rVDRhead))) return CWE;
 	 if (!Write64_64(fp,&(GDR->zVDRhead))) return CWE;
 	 if (!Write64_64(fp,&(GDR->ADRhead))) return CWE;
 	 if (!Write64_64(fp,&(GDR->eof))) return CWE;
+*/
+         if (!Write32s_64(fp,&(GDR->NrVars),5)) return CWE;
+/*
 	 if (!Write32_64(fp,&(GDR->NrVars))) return CWE;
 	 if (!Write32_64(fp,&(GDR->NumAttr))) return CWE;
 	 if (!Write32_64(fp,&(GDR->rMaxRec))) return CWE;
 	 if (!Write32_64(fp,&(GDR->rNumDims))) return CWE;
 	 if (!Write32_64(fp,&(GDR->NzVars))) return CWE;
+*/
 	 if (!Write64_64(fp,&(GDR->UIRhead))) return CWE;
+         if (!Write32s_64(fp,&(GDR->rfuC),3)) return CWE;
+/*
 	 if (!Write32_64(fp,&(GDR->rfuC))) return CWE;
-	 if (!Write32_64(fp,&(GDR->rfuD))) return CWE;
+	 if (!Write32_64(fp,&(GDR->LeapSecondLastUpdated))) return CWE;
 	 if (!Write32_64(fp,&(GDR->rfuE))) return CWE;
+*/
 	 if (!Write32s_64(fp,GDR->rDimSizes,(int)GDR->rNumDims)) return CWE;
 	 break;
        }
@@ -341,6 +353,7 @@ va_dcl
 	   case GDR_rMAXREC: tOffset += (OFF_T) GDR_rMAXREC_OFFSET64; break;
 	   case GDR_rNUMDIMS: tOffset += (OFF_T) GDR_rNUMDIMS_OFFSET64; break;
 	   case GDR_NzVARS: tOffset += (OFF_T) GDR_NzVARS_OFFSET64; break;
+	   case GDR_LEAPSECONDLASTUPDATED: tOffset += (OFF_T) GDR_LEAPSECONDLASTUPDATED_OFFSET64; break;
 /*	   case GDR_UIRHEAD: tOffset += (OFF_T) GDR_UIRHEAD_OFFSET64; break; */
 	   default: return CDF_INTERNAL_ERROR;
 	 }
@@ -383,17 +396,26 @@ va_dcl
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CWE;
 	 if (!Write64_64(fp,&(ADR->RecordSize))) return CWE;
 	 if (!Write32_64(fp,&(ADR->RecordType))) return CWE;
+         if (!Write64s_64(fp,&(ADR->ADRnext),2)) return CWE;
+/*
 	 if (!Write64_64(fp,&(ADR->ADRnext))) return CWE;
 	 if (!Write64_64(fp,&(ADR->AgrEDRhead))) return CWE;
+*/
+         if (!Write32s_64(fp,&(ADR->Scope),5)) return CWE;
+/*
 	 if (!Write32_64(fp,&(ADR->Scope))) return CWE;
 	 if (!Write32_64(fp,&(ADR->Num))) return CWE;
 	 if (!Write32_64(fp,&(ADR->NgrEntries))) return CWE;
 	 if (!Write32_64(fp,&(ADR->MAXgrEntry))) return CWE;
 	 if (!Write32_64(fp,&(ADR->rfuA))) return CWE;
+*/
 	 if (!Write64_64(fp,&(ADR->AzEDRhead))) return CWE;
+         if (!Write32s_64(fp,&(ADR->NzEntries),3)) return CWE;
+/*
 	 if (!Write32_64(fp,&(ADR->NzEntries))) return CWE;
 	 if (!Write32_64(fp,&(ADR->MAXzEntry))) return CWE;
 	 if (!Write32_64(fp,&(ADR->rfuE))) return CWE;
+*/
 	 if (!WRITEv64(ADR->Name,CDF_ATTR_NAME_LEN256,1,fp)) return CWE;
 	 break;
        }
@@ -481,6 +503,9 @@ va_dcl
 	 if (!Write64_64(fp,&(AEDR->RecordSize))) return CWE;
 	 if (!Write32_64(fp,&(AEDR->RecordType))) return CWE;
 	 if (!Write64_64(fp,&(AEDR->AEDRnext))) return CWE;
+         if (!Write32s_64(fp,&(AEDR->AttrNum),9)) return CWE;
+/*
+
 	 if (!Write32_64(fp,&(AEDR->AttrNum))) return CWE;
 	 if (!Write32_64(fp,&(AEDR->DataType))) return CWE;
 	 if (!Write32_64(fp,&(AEDR->Num))) return CWE;
@@ -490,6 +515,7 @@ va_dcl
 	 if (!Write32_64(fp,&(AEDR->rfuC))) return CWE;
 	 if (!Write32_64(fp,&(AEDR->rfuD))) return CWE;
 	 if (!Write32_64(fp,&(AEDR->rfuE))) return CWE;
+*/
 	 if (value != NULL) {
 	   if (!sX(WriteBuffer64(CDF,fp,AEDR->DataType,
 			         AEDR->NumElems,value),&pStatus)) return pStatus;
@@ -580,10 +606,18 @@ va_dcl
 	 if (!Write64_64(fp,&(VDR->RecordSize))) return CWE;
 	 if (!Write32_64(fp,&(VDR->RecordType))) return CWE;
 	 if (!Write64_64(fp,&(VDR->VDRnext))) return CWE;
+         if (!Write32s_64(fp,&(VDR->DataType),2)) return CWE;
+/*
 	 if (!Write32_64(fp,&(VDR->DataType))) return CWE;
 	 if (!Write32_64(fp,&(VDR->MaxRec))) return CWE;
+*/
+         if (!Write64s_64(fp,&(VDR->VXRhead),2)) return CWE;
+/*
 	 if (!Write64_64(fp,&(VDR->VXRhead))) return CWE;
 	 if (!Write64_64(fp,&(VDR->VXRtail))) return CWE;
+*/
+         if (!Write32s_64(fp,&(VDR->Flags),7)) return CWE;
+/*
 	 if (!Write32_64(fp,&(VDR->Flags))) return CWE;
 	 if (!Write32_64(fp,&(VDR->sRecords))) return CWE;
 	 if (!Write32_64(fp,&(VDR->rfuB))) return CWE;
@@ -591,6 +625,7 @@ va_dcl
 	 if (!Write32_64(fp,&(VDR->rfuF))) return CWE;
 	 if (!Write32_64(fp,&(VDR->NumElems))) return CWE;
 	 if (!Write32_64(fp,&(VDR->Num))) return CWE;
+*/
 	 if (!Write64_64(fp,&(VDR->CPRorSPRoffset))) return CWE;
 	 if (!Write32_64(fp,&(VDR->blockingFactor))) return CWE;
 	 if (!WRITEv64(VDR->Name,CDF_VAR_NAME_LEN256,1,fp)) return CWE;
@@ -799,8 +834,11 @@ va_dcl
 	 if (!Write64_64(fp,&(VXR->RecordSize))) return CWE;
 	 if (!Write32_64(fp,&(VXR->RecordType))) return CWE;
 	 if (!Write64_64(fp,&(VXR->VXRnext))) return CWE;
+         if (!Write32s_64(fp,&(VXR->Nentries),2)) return CWE;
+/*
 	 if (!Write32_64(fp,&(VXR->Nentries))) return CWE;
 	 if (!Write32_64(fp,&(VXR->NusedEntries))) return CWE;
+*/
 	 if (!Write32s_64(fp,VXR->First,(int)VXR->Nentries)) return CWE;
          if (!Write32s_64(fp,VXR->Last,(int)VXR->Nentries)) return CWE;
 	 if (!Write64s_64(fp,VXR->Offset,(int)VXR->Nentries)) return CWE;
@@ -949,8 +987,11 @@ va_dcl
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CWE;
 	 if (!Write64_64(fp,&(UIR->RecordSize))) return CWE;
 	 if (!Write32_64(fp,&(UIR->RecordType))) return CWE;
+         if (!Write64s_64(fp,&(UIR->NextUIR),2)) return CWE;
+/*
 	 if (!Write64_64(fp,&(UIR->NextUIR))) return CWE;
 	 if (!Write64_64(fp,&(UIR->PrevUIR))) return CWE;
+*/
 	 break;
        }
        case UIR_RECORDTYPE: {
@@ -1008,8 +1049,11 @@ va_dcl
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CWE;
 	 if (!Write64_64(fp,&(CCR->RecordSize))) return CWE;
 	 if (!Write32_64(fp,&(CCR->RecordType))) return CWE;
+         if (!Write64s_64(fp,&(CCR->CPRoffset),2)) return CWE;
+/*
 	 if (!Write64_64(fp,&(CCR->CPRoffset))) return CWE;
 	 if (!Write64_64(fp,&(CCR->uSize))) return CWE;
+*/
 	 if (!Write32_64(fp,&(CCR->rfuA))) return CWE;
 	 break;
        }
@@ -1073,10 +1117,13 @@ va_dcl
 	 struct CPRstruct64 *CPR = va_arg (ap, struct CPRstruct64 *); int i;
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CWE;
 	 if (!Write64_64(fp,&(CPR->RecordSize))) return CWE;
+         if (!Write32s_64(fp,&(CPR->RecordType),4)) return CWE;
+/*
 	 if (!Write32_64(fp,&(CPR->RecordType))) return CWE;
 	 if (!Write32_64(fp,&(CPR->cType))) return CWE;
 	 if (!Write32_64(fp,&(CPR->rfuA))) return CWE;
 	 if (!Write32_64(fp,&(CPR->pCount))) return CWE;
+*/
 	 for (i = 0; i < CPR->pCount; i++) {
 	    if (!Write32_64(fp,&(CPR->cParms[i]))) return CWE;
 	 }
@@ -1142,10 +1189,13 @@ va_dcl
 	 struct SPRstruct64 *SPR = va_arg (ap, struct SPRstruct64 *); int i;
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CWE;
 	 if (!Write64_64(fp,&(SPR->RecordSize))) return CWE;
+         if (!Write32s_64(fp,&(SPR->RecordType),4)) return CWE;
+/*
 	 if (!Write32_64(fp,&(SPR->RecordType))) return CWE;
 	 if (!Write32_64(fp,&(SPR->sArraysType))) return CWE;
 	 if (!Write32_64(fp,&(SPR->rfuA))) return CWE;
 	 if (!Write32_64(fp,&(SPR->pCount))) return CWE;
+*/
 	 for (i = 0; i < SPR->pCount; i++) {
 	    if (!Write32_64(fp,&(SPR->sArraysParms[i]))) return CWE;
 	 }
@@ -1211,8 +1261,11 @@ va_dcl
 	 struct CVVRstruct64 *CVVR = va_arg (ap, struct CVVRstruct64 *);
 	 if (!SEEKv64(fp,offset,vSEEK_SET)) return CWE;
 	 if (!Write64_64(fp,&(CVVR->RecordSize))) return CWE;
+         if (!Write32s_64(fp,&(CVVR->RecordType),2)) return CWE;
+/*
 	 if (!Write32_64(fp,&(CVVR->RecordType))) return CWE;
 	 if (!Write32_64(fp,&(CVVR->rfuA))) return CWE;
+*/
 	 if (!Write64_64(fp,&(CVVR->cSize))) return CWE;
 	 break;
        }
