@@ -96,6 +96,7 @@ C					! (before padding blanks begin)
 	INTEGER*4 VAR_REC_VARIANCE_OUT
 	INTEGER*4 VAR_DIM_VARIANCES(N_DIMS)
 	INTEGER*4 VAR_DIM_VARIANCES_OUT(N_DIMS)
+	INTEGER*4 LASTUPDATED, LASTUPDATED_OUT
 
 	CHARACTER VARNAME*(CDF_VAR_NAME_LEN256)
 	CHARACTER NEW_VARNAME*(CDF_VAR_NAME_LEN256)
@@ -159,6 +160,7 @@ C					! (before padding blanks begin)
      .	     EPSTRING2_TRUE/'19941013120000'/,
      .	     EPSTRING3_TRUE/'1994-10-13T12:00:00.000Z'/,
      .	     EPSTRING4_TRUE/'1994-10-13T12:00:00.000'/
+	DATA LASTUPDATED/20150701/
 
 C-----------------------------------------------------------------------
 C  NUL-terminate character strings.
@@ -534,6 +536,16 @@ C-----------------------------------------------------------------------
 C	WRITE (6,103) ERRORTEXT(1:LAST_CHAR)
 C 103	FORMAT (/,' ',A,/)
 
+C-----------------------------------------------------------------------
+C  Check last leap second updated.
+C-----------------------------------------------------------------------
+
+	CALL CDF_GET_LEAPSECONDLASTUPDATED (CDF_ID, LASTUPDATED_OUT,
+     .                                      STATUS)
+	IF (STATUS .LT. CDF_OK) CALL QUIT_CDF (STATUS, '23.3')
+C	IF (LASTUPDATED_OUT .NE. LASTUPDATED) 
+C    .    CALL QUIT_CDF (STATUS, '23.4')
+
 C-----------------------------------------------------------------------
 C  Close CDF.
 C-----------------------------------------------------------------------
