@@ -367,7 +367,7 @@ if (!StatusHandlerC2S(status)) return FALSE;
 
 CHECKforABORTso
 if (mLog) WriteOut (stdout, "Printing Header Information...\n");
-if (!WriteHeader(CDFname)) return FALSE;
+if (!WriteHeader(CDFname, varValues, variables)) return FALSE;
 
 /******************************************************************************
 * Write global scope attributes section.
@@ -427,8 +427,10 @@ return TRUE;
 * WriteHeader.
 ******************************************************************************/
 
-Logical WriteHeader (CDFname)
+Logical WriteHeader (CDFname, varValues, variables)
 char *CDFname;
+int varValues;
+char *variables;
 {
 CDFstatus status;
 long encoding, majority, format;
@@ -437,7 +439,7 @@ long dimSizes[CDF_MAX_DIMS];
 long numVars, numZvars, maxRec;
 long numVattrs, numGattrs;
 int  dimN;
-long version, release, increment;
+long lastUpdated = -1L, version, release, increment;
 char sizes[MAX_SIZES_LEN+1], subIncrement;
 char text[MAX_TEXT_LEN+1], tempS[MAX_LINE_LEN+1];
 long compress, compParms[CDF_MAX_DIMS], compPct, checkSum;
@@ -448,6 +450,12 @@ status = CDFlib (GET_, CDF_VERSION_, &version,
 		 NULL_);
 if (!StatusHandlerC2S(status)) return FALSE;
 
+if (version > 2) {
+  status = CDFlib (GET_, CDF_LEAPSECONDLASTUPDATED_, &lastUpdated,
+ 		   NULL_);
+  if (!StatusHandlerC2S(status)) return FALSE;
+} 
+
 WriteOutFP (SKTfp, "\n! CDF created/modified by CDF V%ld.%ld.%ld",
 	    version, release, increment);
 
@@ -551,9 +559,25 @@ status = CDFlib (GET_, CDF_CHECKSUM_, &checkSum,
 if (!StatusHandlerC2S(status)) return FALSE;
 
 /* if (checkSum != NO_CHECKSUM) */
-  WriteOutFP (SKTfp, "\n! CDF_CHECKSUM: %s", ChecksumToken(checkSum)); 
-  WriteOutFP (SKTfp, "\n! (Valid checksum: None, MD5)");
+WriteOutFP (SKTfp, "\n! CDF_CHECKSUM: %s", ChecksumToken(checkSum)); 
+WriteOutFP (SKTfp, "\n! (Valid checksum: None, MD5)");
 
+if (!PriorTo ("3.5.0", version, release, increment)) {
+  if (lastUpdated > -1 || WriteTT2000VarData(varValues, variables)) {
+    if (lastUpdated > -1)
+      WriteOutFP (SKTfp, "\n! CDF_LEAPSECONDLASTUPDATED: %ld", lastUpdated); 
+    else {
+      long year, month, day;
+#if defined(vms)
+      CDFgetLastDateinLeapSecondsTBL (&year, &month, &day);
+#else
+      CDFgetLastDateinLeapSecondsTable (&year, &month, &day);
+#endif
+      WriteOutFP (SKTfp, "\n! CDF_LEAPSECONDLASTUPDATED: %ld", 10000*year+
+                                                               100*month+day);
+    }
+  }
+}
 return TRUE;
 }
 
@@ -1412,6 +1436,7 @@ Logical VariableSelected (varName, variables)
 char *varName;
 char *variables;
 {
+/*
   char *d1, *d2, varNameT[CDF_VAR_NAME_LEN256+1];
   size_t len;
   d1 = variables;
@@ -1429,6 +1454,12 @@ char *variables;
     if (*d1 == NUL) return FALSE;
     d1++;
   }
+*/
+  if (variables == NULL) return FALSE;
+  if (strstr((const char *)variables, (const char *)varName) != NULL)
+    return TRUE;
+  else
+    return FALSE;
 }
 
 /******************************************************************************
@@ -1514,6 +1545,85 @@ CDFstatus status;
   return TRUE;		/* CDF_OK */
 }
 
+/******************************************************************************
+* WriteTT2000VarData.
+******************************************************************************/
+
+Logical WriteTT2000VarData (varValues, variables)
+int varValues;
+char *variables;
+{
+CDFstatus status;
+long numVars, numZvars;
+long varN, recVary, varDataType, maxRec;
+char varName[CDF_VAR_NAME_LEN256+1];
+
+if (varValues == NOvalues) return FALSE;
+status = CDFlib (GET_, CDF_NUMrVARS_, &numVars,
+		       CDF_NUMzVARS_, &numZvars,
+		 NULL_);
+if (!StatusHandlerC2S(status)) return FALSE;
+if (numVars > 0) {
+  for (varN = 0; varN < numVars; varN++) {
+    status = CDFlib (SELECT_, rVAR_, varN,
+                     GET_, rVAR_NAME_, varName,
+                           rVAR_DATATYPE_, &varDataType,
+                           rVAR_RECVARY_, &recVary,
+                           rVAR_MAXREC_, &maxRec,
+                     NULL_);
+    if (!StatusHandlerC2S(status)) return FALSE;
+    if (varDataType == CDF_TIME_TT2000) {
+      switch (varValues) {
+        case NRVvalues:
+          if (!recVary && maxRec == 0) return TRUE;
+          break;
+        case RVvalues:
+          if (!recVary && maxRec > -1) return TRUE;
+          break;
+        case ALLvalues:
+          if (maxRec > -1) return TRUE;
+          break;
+        case NAMEDvalues:
+          if (VariableSelected(varName,variables) && maxRec > -1) return TRUE;
+          break;
+        default:
+          break; 
+      }
+    }
+  }
+}
+if (numZvars > 0) {
+  for (varN = 0; varN < numZvars; varN++) {
+    status = CDFlib (SELECT_, zVAR_, varN,
+                     GET_, zVAR_NAME_, varName,
+                           zVAR_DATATYPE_, &varDataType,
+                           zVAR_RECVARY_, &recVary,
+                           zVAR_MAXREC_, &maxRec,
+                     NULL_);
+    if (!StatusHandlerC2S(status)) return FALSE;
+    if (varDataType == CDF_TIME_TT2000) {
+      switch (varValues) {
+        case NRVvalues:
+          if (!recVary && maxRec == 0) return TRUE;
+          break;
+        case RVvalues:
+          if (!recVary && maxRec > -1) return TRUE;
+          break;
+        case ALLvalues:
+          if (maxRec > -1) return TRUE;
+          break;
+        case NAMEDvalues:
+          if (VariableSelected(varName,variables) && maxRec > -1) return TRUE;
+          break;
+        default:
+          break; 
+      }
+    }
+  }
+}
+return FALSE;
+}
+
 /******************************************************************************
 * SkeletonTableQOPs.
 *    Returns TRUE if execution should continue.
@@ -1613,85 +1723,85 @@ char **argV[];
       * Ok.
       ************************************************************************/
       case OKin: {
-		char *valuesOptions[5] = { "off", "nrv", "rv", "all", NULL };
-		int n;
-		char tempS1[1+1];
-		/**********************************************************************
-		* Get the value of each control.
-		**********************************************************************/
-		GetIText ((Handle) controlHs[CDFTEXTin], CDFtext);
-		GetIText ((Handle) controlHs[SKTTEXTin], sktText);
-		GetIText ((Handle) controlHs[CACHEin], cacheText);
-		GetIText ((Handle) controlHs[VARSin], varsText);
-		outToScreen = GetCtlValue (controlHs[SCREENin]);
-		useFormat = GetCtlValue (controlHs[FORMATin]);
-		negToPos = GetCtlValue (controlHs[NEGZin]);
-		pageOutput = GetCtlValue (controlHs[PAGEin]);
-		reportInfos = GetCtlValue (controlHs[INFOin]);
-		reportWarns = GetCtlValue (controlHs[WARNin]);
-		reportErrors = GetCtlValue (controlHs[ERRORin]);
-		dispStats = GetCtlValue (controlHs[STATSin]);
-		logMsg = GetCtlValue (controlHs[LOGin]);
-		for (varValues = 0; varValues < 5; varValues++) {
-		   if (GetCtlValue(controlHs[VALUESinBASE+varValues])) break;
-		}
-		for (zModeSrc = 0; zModeSrc < 3; zModeSrc++) {
-		   if (GetCtlValue(controlHs[ZMODEinBASE+zModeSrc])) break;
-		}
-		/**********************************************************************
-		* Build argc/argv.
-		**********************************************************************/
-		*argC = 13 + BOO(NULpString(CDFtext),0,1) +
-			     	 BOO(NULpString(sktText),0,2) +
-			     	 BOO(NULpString(cacheText),0,2);
+	char *valuesOptions[5] = { "off", "nrv", "rv", "all", NULL };
+	int n;
+	char tempS1[1+1];
+	/**********************************************************************
+	* Get the value of each control.
+	**********************************************************************/
+	GetIText ((Handle) controlHs[CDFTEXTin], CDFtext);
+	GetIText ((Handle) controlHs[SKTTEXTin], sktText);
+	GetIText ((Handle) controlHs[CACHEin], cacheText);
+	GetIText ((Handle) controlHs[VARSin], varsText);
+	outToScreen = GetCtlValue (controlHs[SCREENin]);
+	useFormat = GetCtlValue (controlHs[FORMATin]);
+	negToPos = GetCtlValue (controlHs[NEGZin]);
+	pageOutput = GetCtlValue (controlHs[PAGEin]);
+	reportInfos = GetCtlValue (controlHs[INFOin]);
+	reportWarns = GetCtlValue (controlHs[WARNin]);
+	reportErrors = GetCtlValue (controlHs[ERRORin]);
+	dispStats = GetCtlValue (controlHs[STATSin]);
+	logMsg = GetCtlValue (controlHs[LOGin]);
+	for (varValues = 0; varValues < 5; varValues++) {
+	   if (GetCtlValue(controlHs[VALUESinBASE+varValues])) break;
+	}
+	for (zModeSrc = 0; zModeSrc < 3; zModeSrc++) {
+	   if (GetCtlValue(controlHs[ZMODEinBASE+zModeSrc])) break;
+	}
+	/**********************************************************************
+	* Build argc/argv.
+	**********************************************************************/
+	*argC = 13 + BOO(NULpString(CDFtext),0,1) +
+		     	 BOO(NULpString(sktText),0,2) +
+		     	 BOO(NULpString(cacheText),0,2);
     	*argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *),
 						  FatalError);
-		n = 0;
-		MAKEstrARGv (argV, n, pgmName)
-		MAKEbooARGv (argV, n, outToScreen, "-screen", "-noscreen")
-		MAKEbooARGv (argV, n, useFormat, "-format", "-noformat")
-		MAKEbooARGv (argV, n, negToPos, "-neg2posfp0", "-noneg2posfp0")
-		MAKEbooARGv (argV, n, pageOutput, "-page", "-nopage")
-		MAKEbooARGv (argV, n, dispStats, "-statistics", "-nostatistics")
-		MAKEbooARGv (argV, n, logMsg, "-log", "-nolog")
-		MAKEstrARGv (argV, n, "-zmode")
-		snprintf (tempS1, (size_t) sizeof(tempS1), "%d", zModeSrc);
-		MAKEstrARGv (argV, n, tempS1)
-		MAKEstrARGv (argV, n, "-report")
-		MAKEstrARGv (argV, n, StatusCodeReportOptions(reportErrors,
+	n = 0;
+	MAKEstrARGv (argV, n, pgmName)
+	MAKEbooARGv (argV, n, outToScreen, "-screen", "-noscreen")
+	MAKEbooARGv (argV, n, useFormat, "-format", "-noformat")
+	MAKEbooARGv (argV, n, negToPos, "-neg2posfp0", "-noneg2posfp0")
+	MAKEbooARGv (argV, n, pageOutput, "-page", "-nopage")
+	MAKEbooARGv (argV, n, dispStats, "-statistics", "-nostatistics")
+	MAKEbooARGv (argV, n, logMsg, "-log", "-nolog")
+	MAKEstrARGv (argV, n, "-zmode")
+	snprintf (tempS1, (size_t) sizeof(tempS1), "%d", zModeSrc);
+	MAKEstrARGv (argV, n, tempS1)
+	MAKEstrARGv (argV, n, "-report")
+	MAKEstrARGv (argV, n, StatusCodeReportOptions(reportErrors,
 						      reportWarns,
 						      reportInfos))
-		MAKEstrARGv (argV, n, "-values")
-		switch (varValues) {
-		  case NAMEDvalues:
-		    PtoCstr (varsText);
-		    MAKEstrARGv (argV, n, (char *) varsText)
-		    CtoPstr ((char *) varsText);
-		    break;
-		  default:
-		    MAKEstrARGv (argV, n, valuesOptions[varValues])
-		    break;
-		}
-		if (!NULpString(sktText)) {
-		  MAKEstrARGv (argV, n, "-skeleton")
-		  PtoCstr (sktText);
-		  MAKEstrARGv (argV, n, (char *) sktText)
-		  CtoPstr ((char *) sktText);
-		}
-		if (!NULpString(cacheText)) {
-		  MAKEstrARGv (argV, n, "-cache")
-		  PtoCstr (cacheText);
-		  MAKEstrARGv (argV, n, (char *) cacheText)
-		  CtoPstr ((char *) cacheText);
-		}
-		if (!NULpString(CDFtext)) {
-		  PtoCstr (CDFtext);
-		  MAKEstrARGv (argV, n, (char *) CDFtext)
-		  CtoPstr ((char *) CDFtext);
-		}
-		/**********************************************************************
-		* Close the dialog and return.
-		**********************************************************************/
+	MAKEstrARGv (argV, n, "-values")
+	switch (varValues) {
+	  case NAMEDvalues:
+	    PtoCstr (varsText);
+	    MAKEstrARGv (argV, n, (char *) varsText)
+	    CtoPstr ((char *) varsText);
+	    break;
+	  default:
+	    MAKEstrARGv (argV, n, valuesOptions[varValues])
+	    break;
+	}
+	if (!NULpString(sktText)) {
+	  MAKEstrARGv (argV, n, "-skeleton")
+	  PtoCstr (sktText);
+	  MAKEstrARGv (argV, n, (char *) sktText)
+	  CtoPstr ((char *) sktText);
+	}
+	if (!NULpString(cacheText)) {
+	  MAKEstrARGv (argV, n, "-cache")
+	  PtoCstr (cacheText);
+	  MAKEstrARGv (argV, n, (char *) cacheText)
+	  CtoPstr ((char *) cacheText);
+	}
+	if (!NULpString(CDFtext)) {
+	  PtoCstr (CDFtext);
+	  MAKEstrARGv (argV, n, (char *) CDFtext)
+	  CtoPstr ((char *) CDFtext);
+	}
+	/**********************************************************************
+	* Close the dialog and return.
+	**********************************************************************/
         CloseDialog (dialogP);
 #ifdef __MWERKS__
         DisposeRoutineDescriptor (FilterDialogQOPsoUPP);
@@ -1706,13 +1816,13 @@ char **argV[];
         int n;
         *argC = 1;
         *argV = (char **) cdf_AllocateMemory ((size_t)*argC * sizeof(char *), FatalError);
-		n = 0;
-		MAKEstrARGv (argV, n, pgmName)
+	n = 0;
+	MAKEstrARGv (argV, n, pgmName)
 #ifdef __MWERKS__
         DisposeRoutineDescriptor (FilterDialogQOPsoUPP);
-		DisposeRoutineDescriptor (OutlineDefaultButtonUPP);
+	DisposeRoutineDescriptor (OutlineDefaultButtonUPP);
 #endif
-		CloseDialog (dialogP);
+	CloseDialog (dialogP);
         return TRUE;
       }
       /************************************************************************
@@ -1721,7 +1831,7 @@ char **argV[];
       case CANCELin:
 #ifdef __MWERKS__
         DisposeRoutineDescriptor (FilterDialogQOPsoUPP);
-		DisposeRoutineDescriptor (OutlineDefaultButtonUPP);
+	DisposeRoutineDescriptor (OutlineDefaultButtonUPP);
 #endif
         CloseDialog (dialogP);
         return FALSE;
@@ -1729,22 +1839,22 @@ char **argV[];
       * Select CDF specification.
       ************************************************************************/
       case CDFSELECTin: {
-		StandardFileReply CDFreply;
-		char CDFpath[DU_MAX_PATH_LEN+1];
+	StandardFileReply CDFreply;
+	char CDFpath[DU_MAX_PATH_LEN+1];
 #ifndef __MWERKS__
-		StandardGetFile (FilterForCDFs, -1, NULL, &CDFreply);
+	StandardGetFile (FilterForCDFs, -1, NULL, &CDFreply);
 #else
-		FilterForCDFsUPP = NewFileFilterProc((ProcPtr) FilterForCDFs);
-		StandardGetFile (FilterForCDFsUPP, -1, NULL, &CDFreply);
-		DisposeRoutineDescriptor (FilterForCDFsUPP);
+	FilterForCDFsUPP = NewFileFilterProc((ProcPtr) FilterForCDFs);
+	StandardGetFile (FilterForCDFsUPP, -1, NULL, &CDFreply);
+	DisposeRoutineDescriptor (FilterForCDFsUPP);
 #endif
-		if (CDFreply.sfGood && !CDFreply.sfIsFolder && !CDFreply.sfIsVolume) {
-		  BuildMacPath (&CDFreply.sfFile, CDFpath, TRUE);
-		  CDFtext[0] = strlen (CDFpath);
-		  strcpyX ((char *) &CDFtext[1], CDFpath, 255);
-		  SetIText ((Handle) controlHs[CDFTEXTin], CDFtext);
-		}
-		break;
+	if (CDFreply.sfGood && !CDFreply.sfIsFolder && !CDFreply.sfIsVolume) {
+	  BuildMacPath (&CDFreply.sfFile, CDFpath, TRUE);
+	  CDFtext[0] = strlen (CDFpath);
+	  strcpyX ((char *) &CDFtext[1], CDFpath, 255);
+	  SetIText ((Handle) controlHs[CDFTEXTin], CDFtext);
+	}
+	break;
       }
       /************************************************************************
       * Select skeleton CDF.
@@ -1752,17 +1862,17 @@ char **argV[];
       * iBeam (instead of returning it to what it was).
       ************************************************************************/
       case SKTSELECTin: {
-		StandardFileReply sktReply;
-		char sktPath[DU_MAX_PATH_LEN+1], prompt[] = "Enter skeleton table:";
-		StandardPutFile (CtoPstr(prompt), CtoPstr(""), &sktReply);
-		if (sktReply.sfGood && !sktReply.sfIsFolder && !sktReply.sfIsVolume) {
-		  BuildMacPath (&sktReply.sfFile, sktPath, TRUE);
-		  sktText[0] = strlen (sktPath);
-		  strcpyX ((char *) &sktText[1], sktPath, 255);
-		  SetIText ((Handle) controlHs[SKTTEXTin], sktText);
-		}
-		SetCursor (&(qd.arrow));
-		break;
+	StandardFileReply sktReply;
+	char sktPath[DU_MAX_PATH_LEN+1], prompt[] = "Enter skeleton table:";
+	StandardPutFile (CtoPstr(prompt), CtoPstr(""), &sktReply);
+	if (sktReply.sfGood && !sktReply.sfIsFolder && !sktReply.sfIsVolume) {
+	  BuildMacPath (&sktReply.sfFile, sktPath, TRUE);
+	  sktText[0] = strlen (sktPath);
+	  strcpyX ((char *) &sktText[1], sktPath, 255);
+	  SetIText ((Handle) controlHs[SKTTEXTin], sktText);
+	}
+	SetCursor (&(qd.arrow));
+	break;
       }
       /************************************************************************
       * Check boxes.
